# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

from pyVmomi.vim.host import ScsiDisk

class DiskResult(DynamicData):
   class State(Enum):
      inUse: ClassVar['State'] = 'inUse'
      eligible: ClassVar['State'] = 'eligible'
      ineligible: ClassVar['State'] = 'ineligible'

   disk: ScsiDisk
   state: str
   vsanUuid: Optional[str] = None
   error: Optional[MethodFault] = None
   degraded: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vm.customization import IpGenerator
from pyVmomi.vim.vm.customization import IpV6Generator

class IPSettings(DynamicData):
   class IpV6AddressSpec(DynamicData):
      ip: list[IpV6Generator] = []
      gateway: list[str] = []

   class NetBIOSMode(Enum):
      enableNetBIOSViaDhcp: ClassVar['NetBIOSMode'] = 'enableNetBIOSViaDhcp'
      enableNetBIOS: ClassVar['NetBIOSMode'] = 'enableNetBIOS'
      disableNetBIOS: ClassVar['NetBIOSMode'] = 'disableNetBIOS'

   ip: IpGenerator
   subnetMask: Optional[str] = None
   gateway: list[str] = []
   ipV6Spec: Optional[IpV6AddressSpec] = None
   dnsServerList: list[str] = []
   dnsDomain: Optional[str] = None
   primaryWINS: Optional[str] = None
   secondaryWINS: Optional[str] = None
   netBIOS: Optional[NetBIOSMode] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

class VsanBurnInTest(DynamicData):
   testname: str
   workload: Optional[str] = None
   duration: long
   result: str



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class FlagInfo(DynamicData):
   class HtSharing(Enum):
      any: ClassVar['HtSharing'] = 'any'
      none: ClassVar['HtSharing'] = 'none'
      internal: ClassVar['HtSharing'] = 'internal'

   class PowerOffBehavior(Enum):
      powerOff: ClassVar['PowerOffBehavior'] = 'powerOff'
      revert: ClassVar['PowerOffBehavior'] = 'revert'
      prompt: ClassVar['PowerOffBehavior'] = 'prompt'
      take: ClassVar['PowerOffBehavior'] = 'take'

   class MonitorType(Enum):
      release: ClassVar['MonitorType'] = 'release'
      debug: ClassVar['MonitorType'] = 'debug'
      stats: ClassVar['MonitorType'] = 'stats'

   class VirtualMmuUsage(Enum):
      automatic: ClassVar['VirtualMmuUsage'] = 'automatic'
      on: ClassVar['VirtualMmuUsage'] = 'on'
      off: ClassVar['VirtualMmuUsage'] = 'off'

   class VirtualExecUsage(Enum):
      hvAuto: ClassVar['VirtualExecUsage'] = 'hvAuto'
      hvOn: ClassVar['VirtualExecUsage'] = 'hvOn'
      hvOff: ClassVar['VirtualExecUsage'] = 'hvOff'

   disableAcceleration: Optional[bool] = None
   enableLogging: Optional[bool] = None
   useToe: Optional[bool] = None
   runWithDebugInfo: Optional[bool] = None
   monitorType: Optional[str] = None
   htSharing: Optional[str] = None
   snapshotDisabled: Optional[bool] = None
   snapshotLocked: Optional[bool] = None
   diskUuidEnabled: Optional[bool] = None
   virtualMmuUsage: Optional[str] = None
   virtualExecUsage: Optional[str] = None
   snapshotPowerOffBehavior: Optional[str] = None
   recordReplayEnabled: Optional[bool] = None
   faultToleranceType: Optional[str] = None
   cbrcCacheEnabled: Optional[bool] = None
   vvtdEnabled: Optional[bool] = None
   vbsEnabled: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import Task

from pyVmomi.vim.cns import QueryFilter
from pyVmomi.vim.cns import QueryResult
from pyVmomi.vim.cns import QuerySelection
from pyVmomi.vim.cns import SnapshotCreateSpec
from pyVmomi.vim.cns import SnapshotDeleteSpec
from pyVmomi.vim.cns import VolumeACLConfigureSpec
from pyVmomi.vim.cns import VolumeAttachDetachSpec
from pyVmomi.vim.cns import VolumeCreateSpec
from pyVmomi.vim.cns import VolumeExtendSpec
from pyVmomi.vim.cns import VolumeId
from pyVmomi.vim.cns import VolumeMetadataUpdateSpec
from pyVmomi.vim.cns import VolumePolicyReconfigSpec
from pyVmomi.vim.cns import VolumeRelocateSpec

class VolumeManager(ManagedObject):
   def Create(self, createSpecs: list[VolumeCreateSpec]) -> Task: ...
   def UpdateVolumeMetadata(self, updateSpecs: list[VolumeMetadataUpdateSpec]) -> Task: ...
   def Delete(self, volumeIds: list[VolumeId], deleteDisk: bool) -> Task: ...
   def Attach(self, attachSpecs: list[VolumeAttachDetachSpec]) -> Task: ...
   def Detach(self, detachSpecs: list[VolumeAttachDetachSpec]) -> Task: ...
   def QueryAsync(self, filter: QueryFilter, selection: Optional[QuerySelection]) -> Task: ...
   def Query(self, filter: QueryFilter, selection: Optional[QuerySelection]) -> QueryResult: ...
   def ConfigureVolumeACLs(self, ACLConfigSpecs: list[VolumeACLConfigureSpec]) -> Task: ...
   def Extend(self, extendSpecs: list[VolumeExtendSpec]) -> Task: ...
   def CreateSnapshots(self, snapshotSpecs: list[SnapshotCreateSpec]) -> Task: ...
   def DeleteSnapshots(self, snapshotDeleteSpecs: list[SnapshotDeleteSpec]) -> Task: ...
   def Relocate(self, relocateSpecs: list[VolumeRelocateSpec]) -> Task: ...
   def ReconfigPolicy(self, volumePolicyReconfigSpecs: list[VolumePolicyReconfigSpec]) -> Task: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vApp import IPAssignmentInfo
from pyVmomi.vim.vApp import OvfSectionInfo
from pyVmomi.vim.vApp import ProductInfo
from pyVmomi.vim.vApp import PropertyInfo

class VmConfigInfo(DynamicData):
   product: list[ProductInfo] = []
   property: list[PropertyInfo] = []
   ipAssignment: IPAssignmentInfo
   eula: list[str] = []
   ovfSection: list[OvfSectionInfo] = []
   ovfEnvironmentTransport: list[str] = []
   installBootRequired: bool
   installBootStopDelay: int



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import ManagedEntity
from pyVmomi.vim import TaskInfo

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.alarm import Alarm

from pyVmomi.vim.scheduler import ScheduledTask

class TaskFilterSpec(DynamicData):
   class RecursionOption(Enum):
      self: ClassVar['RecursionOption'] = 'self'
      children: ClassVar['RecursionOption'] = 'children'
      all: ClassVar['RecursionOption'] = 'all'

   class TimeOption(Enum):
      queuedTime: ClassVar['TimeOption'] = 'queuedTime'
      startedTime: ClassVar['TimeOption'] = 'startedTime'
      completedTime: ClassVar['TimeOption'] = 'completedTime'

   class ByEntity(DynamicData):
      entity: ManagedEntity
      recursion: RecursionOption

   class ByTime(DynamicData):
      timeType: TimeOption
      beginTime: Optional[datetime] = None
      endTime: Optional[datetime] = None

   class ByUsername(DynamicData):
      systemUser: bool
      userList: list[str] = []

   entity: Optional[ByEntity] = None
   time: Optional[ByTime] = None
   userName: Optional[ByUsername] = None
   activationId: list[str] = []
   state: list[TaskInfo.State] = []
   alarm: Optional[Alarm] = None
   scheduledTask: Optional[ScheduledTask] = None
   eventChainId: list[int] = []
   tag: list[str] = []
   parentTaskKey: list[str] = []
   rootTaskKey: list[str] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import ManagedEntity

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.encryption import KeyProviderId
from pyVmomi.vim.encryption import KmipServerInfo

class KmipClusterInfo(DynamicData):
   class KmsManagementType(Enum):
      unknown: ClassVar['KmsManagementType'] = 'unknown'
      vCenter: ClassVar['KmsManagementType'] = 'vCenter'
      trustAuthority: ClassVar['KmsManagementType'] = 'trustAuthority'
      nativeProvider: ClassVar['KmsManagementType'] = 'nativeProvider'

   class KeyType(Enum):
      rawKey: ClassVar['KeyType'] = 'rawKey'
      wrappedKey: ClassVar['KeyType'] = 'wrappedKey'

   class KeyInfo(DynamicData):
      pass

   class WrappingKeyIdKeyInfo(KeyInfo):
      keyId: str
      configuredTime: datetime

   class WrappingRotationIntervalKeyInfo(KeyInfo):
      keyId: Optional[str] = None
      rotationInterval: Optional[int] = None
      lastRotation: Optional[datetime] = None

   clusterId: KeyProviderId
   servers: list[KmipServerInfo] = []
   useAsDefault: bool
   managementType: Optional[str] = None
   useAsEntityDefault: list[ManagedEntity] = []
   hasBackup: Optional[bool] = None
   tpmRequired: Optional[bool] = None
   keyId: Optional[str] = None
   defaultKeyType: Optional[str] = None
   keyInfo: Optional[KeyInfo] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vm import TargetInfo

from pyVmomi.vim.vm.device import VirtualDevice

class VendorDeviceGroupInfo(TargetInfo):
   class ComponentDeviceInfo(DynamicData):
      class ComponentType(Enum):
         pciPassthru: ClassVar['ComponentType'] = 'pciPassthru'
         nvidiaVgpu: ClassVar['ComponentType'] = 'nvidiaVgpu'
         sriovNic: ClassVar['ComponentType'] = 'sriovNic'
         dvx: ClassVar['ComponentType'] = 'dvx'

      type: str
      vendorName: str
      deviceName: str
      isConfigurable: bool
      device: VirtualDevice

   deviceGroupName: str
   deviceGroupDescription: Optional[str] = None
   componentDeviceInfo: list[ComponentDeviceInfo] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import RuleInfo

from pyVmomi.vim.option import OptionValue

from pyVmomi.vim.storageDrs import AutomationConfig
from pyVmomi.vim.storageDrs import IoLoadBalanceConfig
from pyVmomi.vim.storageDrs import SpaceLoadBalanceConfig

class PodConfigInfo(DynamicData):
   class Behavior(Enum):
      manual: ClassVar['Behavior'] = 'manual'
      automated: ClassVar['Behavior'] = 'automated'

   enabled: bool
   ioLoadBalanceEnabled: bool
   defaultVmBehavior: str
   loadBalanceInterval: Optional[int] = None
   defaultIntraVmAffinity: Optional[bool] = None
   spaceLoadBalanceConfig: Optional[SpaceLoadBalanceConfig] = None
   ioLoadBalanceConfig: Optional[IoLoadBalanceConfig] = None
   automationOverrides: Optional[AutomationConfig] = None
   rule: list[RuleInfo] = []
   option: list[OptionValue] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import ConnectSpec

from pyVmomi.vim.vsan import DataEfficiencyConfig
from pyVmomi.vim.vsan import VsanDeconvergedNetConfig

from pyVmomi.vim.vsan.host import CreateNativeKeyProviderSpec
from pyVmomi.vim.vsan.host import EncryptionInfo

class VsanVcPostDeployConfigSpec(DynamicData):
   dcName: Optional[str] = None
   clusterName: Optional[str] = None
   firstHost: Optional[ConnectSpec] = None
   hostsToAdd: list[ConnectSpec] = []
   vsanDataEfficiencyConfig: Optional[DataEfficiencyConfig] = None
   vsanLicenseKey: Optional[str] = None
   hostLicenseKey: Optional[str] = None
   taskId: Optional[str] = None
   vsanDataEncryptionConfig: Optional[EncryptionInfo] = None
   createNativeKeyProviderSpec: Optional[CreateNativeKeyProviderSpec] = None
   vsanClusterMode: Optional[str] = None
   deconvergedNetConfig: Optional[VsanDeconvergedNetConfig] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import Task

from pyVmomi.sms.provider import AlarmFilter
from pyVmomi.sms.provider import AlarmResult
from pyVmomi.sms.provider import Provider

from pyVmomi.sms.storage.replication import FailoverParam
from pyVmomi.sms.storage.replication import GroupOperationResult
from pyVmomi.sms.storage.replication import PromoteParam
from pyVmomi.sms.storage.replication import QueryPointInTimeReplicaParam
from pyVmomi.sms.storage.replication import QueryReplicationPeerResult
from pyVmomi.sms.storage.replication import TestFailoverParam

from pyVmomi.vim.vm.replication import FaultDomainId
from pyVmomi.vim.vm.replication import ReplicationGroupId

class VasaProvider(Provider):
   def Sync(self, arrayId: Optional[str]) -> Task: ...
   def RefreshCertificate(self) -> Task: ...
   def RevokeCertificate(self) -> Task: ...
   def Reconnect(self) -> Task: ...
   def QueryReplicationPeer(self, faultDomainId: list[FaultDomainId]) -> list[QueryReplicationPeerResult]: ...
   def QueryReplicationGroup(self, groupId: list[ReplicationGroupId]) -> list[GroupOperationResult]: ...
   def QueryPointInTimeReplica(self, groupId: list[ReplicationGroupId], queryParam: Optional[QueryPointInTimeReplicaParam]) -> list[GroupOperationResult]: ...
   def TestFailoverReplicationGroupStart(self, testFailoverParam: TestFailoverParam) -> Task: ...
   def TestFailoverReplicationGroupStop(self, groupId: list[ReplicationGroupId], force: bool) -> Task: ...
   def PromoteReplicationGroup(self, promoteParam: PromoteParam) -> Task: ...
   def SyncReplicationGroup(self, groupId: list[ReplicationGroupId], pitName: str) -> Task: ...
   def PrepareFailoverReplicationGroup(self, groupId: list[ReplicationGroupId]) -> Task: ...
   def FailoverReplicationGroup(self, failoverParam: FailoverParam) -> Task: ...
   def ReverseReplicateGroup(self, groupId: list[ReplicationGroupId]) -> Task: ...
   def QueryActiveAlarm(self, alarmFilter: Optional[AlarmFilter]) -> Optional[AlarmResult]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import KeyValue

from pyVmomi.vmodl import DynamicData

class DhcpConfigSpec(DynamicData):
   class DhcpOptionsSpec(DynamicData):
      enable: Optional[bool] = None
      config: list[KeyValue] = []
      operation: str

   ipv6: Optional[DhcpOptionsSpec] = None
   ipv4: Optional[DhcpOptionsSpec] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import KeyAnyValue

from pyVmomi.vim.host import ActiveDirectorySpec
from pyVmomi.vim.host import AssignableHardwareConfig
from pyVmomi.vim.host import DateTimeConfig
from pyVmomi.vim.host import FirewallConfig
from pyVmomi.vim.host import GraphicsConfig
from pyVmomi.vim.host import LicenseSpec
from pyVmomi.vim.host import LocalAccountManager
from pyVmomi.vim.host import MemorySpec
from pyVmomi.vim.host import NasVolume
from pyVmomi.vim.host import NetworkConfig
from pyVmomi.vim.host import SecuritySpec
from pyVmomi.vim.host import ServiceConfig
from pyVmomi.vim.host import StorageDeviceInfo
from pyVmomi.vim.host import VirtualNicManager

from pyVmomi.vim.option import OptionValue

class ConfigSpec(DynamicData):
   nasDatastore: list[NasVolume.Config] = []
   network: Optional[NetworkConfig] = None
   nicTypeSelection: list[VirtualNicManager.NicTypeSelection] = []
   service: list[ServiceConfig] = []
   firewall: Optional[FirewallConfig] = None
   option: list[OptionValue] = []
   datastorePrincipal: Optional[str] = None
   datastorePrincipalPasswd: Optional[str] = None
   datetime: Optional[DateTimeConfig] = None
   storageDevice: Optional[StorageDeviceInfo] = None
   license: Optional[LicenseSpec] = None
   security: Optional[SecuritySpec] = None
   userAccount: list[LocalAccountManager.AccountSpecification] = []
   usergroupAccount: list[LocalAccountManager.AccountSpecification] = []
   memory: Optional[MemorySpec] = None
   activeDirectory: list[ActiveDirectorySpec] = []
   genericConfig: list[KeyAnyValue] = []
   graphicsConfig: Optional[GraphicsConfig] = None
   assignableHardwareConfig: Optional[AssignableHardwareConfig] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

class VsanDiskRebalanceResult(DynamicData):
   status: str
   bytesMoving: Optional[long] = None
   remainingBytesToMove: Optional[long] = None
   diskUsage: Optional[float] = None
   maxDiskUsage: Optional[float] = None
   minDiskUsage: Optional[float] = None
   avgDiskUsage: Optional[float] = None
   diskCompUsage: Optional[float] = None
   maxDiskCompUsage: Optional[float] = None
   minDiskCompUsage: Optional[float] = None
   avgDiskCompUsage: Optional[float] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vim import Network

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vsan import FileServiceDomainConfig

class FileServiceConfig(DynamicData):
   enabled: bool
   fileServerMemoryMB: Optional[long] = None
   fileServerCPUMhz: Optional[long] = None
   fsvmMemoryMB: Optional[long] = None
   fsvmCPU: Optional[long] = None
   network: Optional[Network] = None
   domains: list[FileServiceDomainConfig] = []
   fileAnalyticsEnabled: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import OvfConsumer

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vApp import EntityConfigInfo

class ImportSpec(DynamicData):
   entityConfig: Optional[EntityConfigInfo] = None
   instantiationOst: Optional[OvfConsumer.OstNode] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .CryptoKeyId import CryptoKeyId as CryptoKeyId
from .CryptoKeyPlain import CryptoKeyPlain as CryptoKeyPlain
from .CryptoKeyResult import CryptoKeyResult as CryptoKeyResult
from .CryptoManager import CryptoManager as CryptoManager
from .CryptoManagerHost import CryptoManagerHost as CryptoManagerHost
from .CryptoManagerHostKMS import CryptoManagerHostKMS as CryptoManagerHostKMS
from .CryptoManagerKmip import CryptoManagerKmip as CryptoManagerKmip
from .CryptoSpec import CryptoSpec as CryptoSpec
from .CryptoSpecDecrypt import CryptoSpecDecrypt as CryptoSpecDecrypt
from .CryptoSpecDeepRecrypt import CryptoSpecDeepRecrypt as CryptoSpecDeepRecrypt
from .CryptoSpecEncrypt import CryptoSpecEncrypt as CryptoSpecEncrypt
from .CryptoSpecNoOp import CryptoSpecNoOp as CryptoSpecNoOp
from .CryptoSpecRegister import CryptoSpecRegister as CryptoSpecRegister
from .CryptoSpecShallowRecrypt import CryptoSpecShallowRecrypt as CryptoSpecShallowRecrypt
from .KeyProviderId import KeyProviderId as KeyProviderId
from .KmipClusterInfo import KmipClusterInfo as KmipClusterInfo
from .KmipServerInfo import KmipServerInfo as KmipServerInfo
from .KmipServerSpec import KmipServerSpec as KmipServerSpec
from .KmipServerStatus import KmipServerStatus as KmipServerStatus



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .DatastoreSyncStatus import DatastoreSyncStatus as DatastoreSyncStatus
from .VStorageObjectAssociations import VStorageObjectAssociations as VStorageObjectAssociations
from .VStorageObjectManager import VStorageObjectManager as VStorageObjectManager
from .VStorageObjectQueryResult import VStorageObjectQueryResult as VStorageObjectQueryResult
from .VStorageObjectQuerySpec import VStorageObjectQuerySpec as VStorageObjectQuerySpec
from .VStorageObjectResult import VStorageObjectResult as VStorageObjectResult
from .VStorageObjectSnapshotResult import VStorageObjectSnapshotResult as VStorageObjectSnapshotResult



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.vim import HostSystem
from pyVmomi.vim import ManagedEntity
from pyVmomi.vim import SharesInfo
from pyVmomi.vim import Task
from pyVmomi.vim import VirtualMachine

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.dvs import DistributedVirtualPort
from pyVmomi.vim.dvs import DistributedVirtualPortgroup
from pyVmomi.vim.dvs import EntityBackup
from pyVmomi.vim.dvs import HostMember
from pyVmomi.vim.dvs import HostProductSpec
from pyVmomi.vim.dvs import KeyedOpaqueBlob
from pyVmomi.vim.dvs import NetworkResourcePool
from pyVmomi.vim.dvs import PortCriteria
from pyVmomi.vim.dvs import ProductSpec
from pyVmomi.vim.dvs import VmVnicNetworkResourcePool

class DistributedVirtualSwitch(ManagedEntity):
   class ProductSpecOperationType(Enum):
      preInstall: ClassVar['ProductSpecOperationType'] = 'preInstall'
      upgrade: ClassVar['ProductSpecOperationType'] = 'upgrade'
      notifyAvailableUpgrade: ClassVar['ProductSpecOperationType'] = 'notifyAvailableUpgrade'
      proceedWithUpgrade: ClassVar['ProductSpecOperationType'] = 'proceedWithUpgrade'
      updateBundleInfo: ClassVar['ProductSpecOperationType'] = 'updateBundleInfo'

   class ContactInfo(DynamicData):
      name: Optional[str] = None
      contact: Optional[str] = None

   class NicTeamingPolicyMode(Enum):
      loadbalance_ip: ClassVar['NicTeamingPolicyMode'] = 'loadbalance_ip'
      loadbalance_srcmac: ClassVar['NicTeamingPolicyMode'] = 'loadbalance_srcmac'
      loadbalance_srcid: ClassVar['NicTeamingPolicyMode'] = 'loadbalance_srcid'
      failover_explicit: ClassVar['NicTeamingPolicyMode'] = 'failover_explicit'
      loadbalance_loadbased: ClassVar['NicTeamingPolicyMode'] = 'loadbalance_loadbased'

   class NetworkResourceManagementCapability(DynamicData):
      networkResourceManagementSupported: bool
      networkResourcePoolHighShareValue: int
      qosSupported: bool
      userDefinedNetworkResourcePoolsSupported: bool
      networkResourceControlVersion3Supported: Optional[bool] = None
      userDefinedInfraTrafficPoolSupported: Optional[bool] = None

   class RollbackCapability(DynamicData):
      rollbackSupported: bool

   class BackupRestoreCapability(DynamicData):
      backupRestoreSupported: bool

   class FeatureCapability(DynamicData):
      networkResourceManagementSupported: bool
      vmDirectPathGen2Supported: Optional[bool] = None
      nicTeamingPolicy: list[str] = []
      networkResourcePoolHighShareValue: Optional[int] = None
      networkResourceManagementCapability: Optional[NetworkResourceManagementCapability] = None
      healthCheckCapability: Optional[HealthCheckFeatureCapability] = None
      rollbackCapability: Optional[RollbackCapability] = None
      backupRestoreCapability: Optional[BackupRestoreCapability] = None
      networkFilterSupported: Optional[bool] = None
      macLearningSupported: Optional[bool] = None

   class HealthCheckFeatureCapability(DynamicData):
      pass

   class Capability(DynamicData):
      dvsOperationSupported: Optional[bool] = None
      dvPortGroupOperationSupported: Optional[bool] = None
      dvPortOperationSupported: Optional[bool] = None
      compatibleHostComponentProductInfo: list[HostProductSpec] = []
      featuresSupported: Optional[FeatureCapability] = None

   class Summary(DynamicData):
      name: str
      uuid: str
      numPorts: int
      productInfo: Optional[ProductSpec] = None
      hostMember: list[HostSystem] = []
      vm: list[VirtualMachine] = []
      host: list[HostSystem] = []
      portgroupName: list[str] = []
      description: Optional[str] = None
      contact: Optional[ContactInfo] = None
      numHosts: Optional[int] = None

   class SwitchPolicy(DynamicData):
      autoPreInstallAllowed: Optional[bool] = None
      autoUpgradeAllowed: Optional[bool] = None
      partialUpgradeAllowed: Optional[bool] = None

   class UplinkPortPolicy(DynamicData):
      pass

   class NameArrayUplinkPortPolicy(UplinkPortPolicy):
      uplinkPortName: list[str] = []

   class ConfigSpec(DynamicData):
      configVersion: Optional[str] = None
      name: Optional[str] = None
      numStandalonePorts: Optional[int] = None
      maxPorts: Optional[int] = None
      uplinkPortPolicy: Optional[UplinkPortPolicy] = None
      uplinkPortgroup: list[DistributedVirtualPortgroup] = []
      defaultPortConfig: Optional[DistributedVirtualPort.Setting] = None
      host: list[HostMember.ConfigSpec] = []
      extensionKey: Optional[str] = None
      description: Optional[str] = None
      policy: Optional[SwitchPolicy] = None
      vendorSpecificConfig: list[KeyedOpaqueBlob] = []
      contact: Optional[ContactInfo] = None
      switchIpAddress: Optional[str] = None
      defaultProxySwitchMaxNumPorts: Optional[int] = None
      infrastructureTrafficResourceConfig: list[HostInfrastructureTrafficResource] = []
      netResourcePoolTrafficResourceConfig: list[HostInfrastructureTrafficResource] = []
      networkResourceControlVersion: Optional[str] = None

   class CreateSpec(DynamicData):
      configSpec: ConfigSpec
      productInfo: Optional[ProductSpec] = None
      capability: Optional[Capability] = None

   class ConfigInfo(DynamicData):
      uuid: str
      name: str
      numStandalonePorts: int
      numPorts: int
      maxPorts: int
      uplinkPortPolicy: UplinkPortPolicy
      uplinkPortgroup: list[DistributedVirtualPortgroup] = []
      defaultPortConfig: DistributedVirtualPort.Setting
      host: list[HostMember] = []
      productInfo: ProductSpec
      targetInfo: Optional[ProductSpec] = None
      extensionKey: Optional[str] = None
      vendorSpecificConfig: list[KeyedOpaqueBlob] = []
      policy: Optional[SwitchPolicy] = None
      description: Optional[str] = None
      configVersion: str
      contact: ContactInfo
      switchIpAddress: Optional[str] = None
      createTime: datetime
      networkResourceManagementEnabled: bool
      defaultProxySwitchMaxNumPorts: Optional[int] = None
      healthCheckConfig: list[HealthCheckConfig] = []
      infrastructureTrafficResourceConfig: list[HostInfrastructureTrafficResource] = []
      netResourcePoolTrafficResourceConfig: list[HostInfrastructureTrafficResource] = []
      networkResourceControlVersion: Optional[str] = None
      vmVnicNetworkResourcePool: list[VmVnicNetworkResourcePool] = []
      pnicCapacityRatioForReservation: Optional[int] = None

   class NetworkResourceControlVersion(Enum):
      version2: ClassVar['NetworkResourceControlVersion'] = 'version2'
      version3: ClassVar['NetworkResourceControlVersion'] = 'version3'

   class HostInfrastructureTrafficClass(Enum):
      management: ClassVar['HostInfrastructureTrafficClass'] = 'management'
      faultTolerance: ClassVar['HostInfrastructureTrafficClass'] = 'faultTolerance'
      vmotion: ClassVar['HostInfrastructureTrafficClass'] = 'vmotion'
      virtualMachine: ClassVar['HostInfrastructureTrafficClass'] = 'virtualMachine'
      iSCSI: ClassVar['HostInfrastructureTrafficClass'] = 'iSCSI'
      nfs: ClassVar['HostInfrastructureTrafficClass'] = 'nfs'
      hbr: ClassVar['HostInfrastructureTrafficClass'] = 'hbr'
      vsan: ClassVar['HostInfrastructureTrafficClass'] = 'vsan'
      vdp: ClassVar['HostInfrastructureTrafficClass'] = 'vdp'
      backupNfc: ClassVar['HostInfrastructureTrafficClass'] = 'backupNfc'
      nvmetcp: ClassVar['HostInfrastructureTrafficClass'] = 'nvmetcp'
      provisioning: ClassVar['HostInfrastructureTrafficClass'] = 'provisioning'

   class HostInfrastructureTrafficResource(DynamicData):
      class ResourceAllocation(DynamicData):
         limit: Optional[long] = None
         shares: Optional[SharesInfo] = None
         reservation: Optional[long] = None

      key: str
      description: Optional[str] = None
      allocationInfo: ResourceAllocation

   class HealthCheckConfig(DynamicData):
      enable: Optional[bool] = None
      interval: Optional[int] = None

   class ResourceRuntimeInfo(DynamicData):
      capacity: Optional[int] = None
      usage: Optional[int] = None
      available: Optional[int] = None
      allocatedResource: list[VmVnicNetworkResourcePool.VnicAllocatedResource] = []
      vmVnicNetworkResourcePoolRuntime: list[VmVnicNetworkResourcePool.RuntimeInfo] = []

   class RuntimeInfo(DynamicData):
      hostMemberRuntime: list[HostMember.RuntimeInfo] = []
      resourceRuntimeInfo: Optional[ResourceRuntimeInfo] = None

   @property
   def uuid(self) -> str: ...
   @property
   def capability(self) -> Capability: ...
   @property
   def summary(self) -> Summary: ...
   @property
   def config(self) -> ConfigInfo: ...
   @property
   def networkResourcePool(self) -> list[NetworkResourcePool]: ...
   @property
   def portgroup(self) -> list[DistributedVirtualPortgroup]: ...
   @property
   def runtime(self) -> Optional[RuntimeInfo]: ...

   def FetchPortKeys(self, criteria: Optional[PortCriteria]) -> list[str]: ...
   def FetchPorts(self, criteria: Optional[PortCriteria]) -> list[DistributedVirtualPort]: ...
   def QueryUsedVlanId(self) -> list[int]: ...
   def Reconfigure(self, spec: ConfigSpec) -> Task: ...
   def PerformProductSpecOperation(self, operation: str, productSpec: Optional[ProductSpec]) -> Task: ...
   def Merge(self, dvs: DistributedVirtualSwitch) -> Task: ...
   def AddPortgroups(self, spec: list[DistributedVirtualPortgroup.ConfigSpec]) -> Task: ...
   def MovePort(self, portKey: list[str], destinationPortgroupKey: Optional[str]) -> Task: ...
   def UpdateCapability(self, capability: Capability) -> NoReturn: ...
   def ReconfigurePort(self, port: list[DistributedVirtualPort.ConfigSpec]) -> Task: ...
   def RefreshPortState(self, portKeys: list[str]) -> NoReturn: ...
   def RectifyHost(self, hosts: list[HostSystem]) -> Task: ...
   def UpdateNetworkResourcePool(self, configSpec: list[NetworkResourcePool.ConfigSpec]) -> NoReturn: ...
   def AddNetworkResourcePool(self, configSpec: list[NetworkResourcePool.ConfigSpec]) -> NoReturn: ...
   def RemoveNetworkResourcePool(self, key: list[str]) -> NoReturn: ...
   def ReconfigureVmVnicNetworkResourcePool(self, configSpec: list[VmVnicNetworkResourcePool.ConfigSpec]) -> Task: ...
   def EnableNetworkResourceManagement(self, enable: bool) -> NoReturn: ...
   def Rollback(self, entityBackup: Optional[EntityBackup.Config]) -> Task: ...
   def AddPortgroup(self, spec: DistributedVirtualPortgroup.ConfigSpec) -> Task: ...
   def UpdateHealthCheckConfig(self, healthCheckConfig: list[HealthCheckConfig]) -> Task: ...
   def LookupPortgroup(self, portgroupKey: str) -> Optional[DistributedVirtualPortgroup]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject
from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

class KernelModuleSystem(ManagedObject):
   class ModuleInfo(DynamicData):
      class SectionInfo(DynamicData):
         address: long
         length: Optional[int] = None

      id: int
      name: str
      version: str
      filename: str
      optionString: str
      loaded: bool
      enabled: bool
      useCount: int
      readOnlySection: SectionInfo
      writableSection: SectionInfo
      textSection: SectionInfo
      dataSection: SectionInfo
      bssSection: SectionInfo

   def QueryModules(self) -> list[ModuleInfo]: ...
   def UpdateModuleOptionString(self, name: str, options: str) -> NoReturn: ...
   def QueryConfiguredModuleOptionString(self, name: str) -> str: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.action import Action

from pyVmomi.vim.scheduler import TaskScheduler

class ScheduledTaskSpec(DynamicData):
   name: str
   description: str
   enabled: bool
   scheduler: TaskScheduler
   action: Action
   notification: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class VsanPerfMetricId(DynamicData):
   class VsanPerfSummaryType(Enum):
      average: ClassVar['VsanPerfSummaryType'] = 'average'
      maximum: ClassVar['VsanPerfSummaryType'] = 'maximum'
      minimum: ClassVar['VsanPerfSummaryType'] = 'minimum'
      latest: ClassVar['VsanPerfSummaryType'] = 'latest'
      summation: ClassVar['VsanPerfSummaryType'] = 'summation'
      none: ClassVar['VsanPerfSummaryType'] = 'none'
      VsanPerfSummaryType_Unknown: ClassVar['VsanPerfSummaryType'] = 'VsanPerfSummaryType_Unknown'

   class VsanPerfStatsType(Enum):
      absolute: ClassVar['VsanPerfStatsType'] = 'absolute'
      delta: ClassVar['VsanPerfStatsType'] = 'delta'
      rate: ClassVar['VsanPerfStatsType'] = 'rate'
      VsanPerfStatsType_Unknown: ClassVar['VsanPerfStatsType'] = 'VsanPerfStatsType_Unknown'

   label: str
   group: Optional[str] = None
   rollupType: Optional[str] = None
   statsType: Optional[str] = None
   name: Optional[str] = None
   description: Optional[str] = None
   metricsCollectInterval: Optional[int] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import VsanClusterHealthTest

class VsanHealthExtMgmtPreCheckResult(DynamicData):
   overallResult: bool
   esxVersionCheckPassed: Optional[bool] = None
   drsCheckPassed: Optional[bool] = None
   eamConnectionCheckPassed: Optional[bool] = None
   installStateCheckPassed: Optional[bool] = None
   results: list[VsanClusterHealthTest] = []
   vumRegistered: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class ForkConfigInfo(DynamicData):
   class ChildType(Enum):
      none: ClassVar['ChildType'] = 'none'
      persistent: ClassVar['ChildType'] = 'persistent'
      nonpersistent: ClassVar['ChildType'] = 'nonpersistent'

   parentEnabled: Optional[bool] = None
   childForkGroupId: Optional[str] = None
   parentForkGroupId: Optional[str] = None
   childType: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class ArrayUpdateSpec(DynamicData):
   class Operation(Enum):
      add: ClassVar['Operation'] = 'add'
      remove: ClassVar['Operation'] = 'remove'
      edit: ClassVar['Operation'] = 'edit'

   operation: Operation
   removeKey: Optional[object] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import Datastore
from pyVmomi.vim import HostSystem

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import DasHostInfo

class DasAdvancedRuntimeInfo(DynamicData):
   class VmcpCapabilityInfo(DynamicData):
      storageAPDSupported: bool
      storagePDLSupported: bool

   class HeartbeatDatastoreInfo(DynamicData):
      datastore: Datastore
      hosts: list[HostSystem] = []

   dasHostInfo: Optional[DasHostInfo] = None
   vmcpSupported: Optional[VmcpCapabilityInfo] = None
   heartbeatDatastoreInfo: list[HeartbeatDatastoreInfo] = []



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .HostCommunication import HostCommunication as HostCommunication
from .HostNotConnected import HostNotConnected as HostNotConnected
from .HostNotReachable import HostNotReachable as HostNotReachable
from .InvalidArgument import InvalidArgument as InvalidArgument
from .InvalidRequest import InvalidRequest as InvalidRequest
from .InvalidType import InvalidType as InvalidType
from .ManagedObjectNotFound import ManagedObjectNotFound as ManagedObjectNotFound
from .MethodNotFound import MethodNotFound as MethodNotFound
from .NotEnoughLicenses import NotEnoughLicenses as NotEnoughLicenses
from .NotImplemented import NotImplemented as NotImplemented
from .NotSupported import NotSupported as NotSupported
from .RequestCanceled import RequestCanceled as RequestCanceled
from .SecurityError import SecurityError as SecurityError
from .SystemError import SystemError as SystemError
from .UnexpectedFault import UnexpectedFault as UnexpectedFault



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

class VsanProactiveRebalanceInfoEx(DynamicData):
   running: Optional[bool] = None
   startTs: Optional[datetime] = None
   stopTs: Optional[datetime] = None
   varianceThreshold: Optional[float] = None
   timeThreshold: Optional[int] = None
   rateThreshold: Optional[int] = None
   hostname: Optional[str] = None
   error: Optional[MethodFault] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.dvs import DistributedVirtualPortgroup

class DistributedVirtualPortgroupInfo(DynamicData):
   switchName: str
   switchUuid: str
   portgroupName: str
   portgroupKey: str
   portgroupType: str
   uplinkPortgroup: bool
   portgroup: DistributedVirtualPortgroup
   networkReservationSupported: Optional[bool] = None
   backingType: Optional[str] = None
   logicalSwitchUuid: Optional[str] = None
   segmentId: Optional[str] = None
   subnetId: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import PropertyPath

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import LocalizableMessage

from pyVmomi.vim.host import ConfigSpec

from pyVmomi.vim.profile import DeferredPolicyOptionParameter
from pyVmomi.vim.profile import ProfilePropertyPath

class ExecuteResult(DynamicData):
   class Status(Enum):
      success: ClassVar['Status'] = 'success'
      needInput: ClassVar['Status'] = 'needInput'
      error: ClassVar['Status'] = 'error'

   class ExecuteError(DynamicData):
      path: Optional[ProfilePropertyPath] = None
      message: LocalizableMessage

   status: str
   configSpec: Optional[ConfigSpec] = None
   inapplicablePath: list[PropertyPath] = []
   requireInput: list[DeferredPolicyOptionParameter] = []
   error: list[ExecuteError] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import DiskDimensions
from pyVmomi.vim.host import ScsiLun

from pyVmomi.vim.vsan.host import VsanDiskInfo

class ScsiDisk(ScsiLun):
   class Partition(DynamicData):
      diskName: str
      partition: int

   class ScsiDiskType(Enum):
      native512: ClassVar['ScsiDiskType'] = 'native512'
      emulated512: ClassVar['ScsiDiskType'] = 'emulated512'
      native4k: ClassVar['ScsiDiskType'] = 'native4k'
      SoftwareEmulated4k: ClassVar['ScsiDiskType'] = 'SoftwareEmulated4k'
      unknown: ClassVar['ScsiDiskType'] = 'unknown'

   capacity: DiskDimensions.Lba
   devicePath: str
   ssd: Optional[bool] = None
   localDisk: Optional[bool] = None
   physicalLocation: list[str] = []
   emulatedDIXDIFEnabled: Optional[bool] = None
   vsanDiskInfo: Optional[VsanDiskInfo] = None
   scsiDiskType: Optional[str] = None
   usedByMemoryTiering: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vm import DiskDeviceInfo

class IdeDiskDeviceInfo(DiskDeviceInfo):
   class PartitionInfo(DynamicData):
      id: int
      capacity: int

   partitionTable: list[PartitionInfo] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim.cluster import Action

class HostPowerAction(Action):
   class OperationType(Enum):
      powerOn: ClassVar['OperationType'] = 'powerOn'
      powerOff: ClassVar['OperationType'] = 'powerOff'

   operationType: OperationType
   powerConsumptionWatt: Optional[int] = None
   cpuCapacityMHz: Optional[int] = None
   memCapacityMB: Optional[int] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import VsanVsanClusterPcapGroup

from pyVmomi.vim.host import VsanVsanPcapResult

class VsanVsanClusterPcapResult(DynamicData):
   pkts: list[str] = []
   groups: list[VsanVsanClusterPcapGroup] = []
   issues: list[str] = []
   hostResults: list[VsanVsanPcapResult] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import ManagedMethod
from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import Task

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import LocalizableMessage

class FailoverClusterManager(ManagedObject):
   class VchaNodeRole(Enum):
      active: ClassVar['VchaNodeRole'] = 'active'
      passive: ClassVar['VchaNodeRole'] = 'passive'
      witness: ClassVar['VchaNodeRole'] = 'witness'

   class VchaClusterMode(Enum):
      enabled: ClassVar['VchaClusterMode'] = 'enabled'
      disabled: ClassVar['VchaClusterMode'] = 'disabled'
      maintenance: ClassVar['VchaClusterMode'] = 'maintenance'

   class VchaClusterState(Enum):
      healthy: ClassVar['VchaClusterState'] = 'healthy'
      degraded: ClassVar['VchaClusterState'] = 'degraded'
      isolated: ClassVar['VchaClusterState'] = 'isolated'

   class VchaNodeState(Enum):
      up: ClassVar['VchaNodeState'] = 'up'
      down: ClassVar['VchaNodeState'] = 'down'

   class VchaNodeRuntimeInfo(DynamicData):
      nodeState: str
      nodeRole: str
      nodeIp: str

   class VchaClusterRuntimeInfo(DynamicData):
      clusterState: str
      nodeInfo: list[VchaNodeRuntimeInfo] = []
      clusterMode: str

   class VchaClusterHealth(DynamicData):
      runtimeInfo: VchaClusterRuntimeInfo
      healthMessages: list[LocalizableMessage] = []
      additionalInformation: list[LocalizableMessage] = []

   @property
   def disabledClusterMethod(self) -> list[ManagedMethod]: ...

   def SetClusterMode(self, mode: str) -> Task: ...
   def GetClusterMode(self) -> str: ...
   def GetClusterHealth(self) -> VchaClusterHealth: ...
   def InitiateFailover(self, planned: bool) -> Task: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import Datastore
from pyVmomi.vim import Folder
from pyVmomi.vim import HostSystem
from pyVmomi.vim import ResourcePool
from pyVmomi.vim import ServiceLocator

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.encryption import CryptoSpec

from pyVmomi.vim.vm import BaseIndependentFilterSpec
from pyVmomi.vim.vm import ProfileSpec

from pyVmomi.vim.vm.device import VirtualDevice
from pyVmomi.vim.vm.device import VirtualDeviceSpec

class RelocateSpec(DynamicData):
   class Transformation(Enum):
      flat: ClassVar['Transformation'] = 'flat'
      sparse: ClassVar['Transformation'] = 'sparse'

   class DiskLocator(DynamicData):
      class BackingSpec(DynamicData):
         parent: Optional[BackingSpec] = None
         crypto: Optional[CryptoSpec] = None

      diskId: int
      datastore: Datastore
      diskMoveType: Optional[str] = None
      diskBackingInfo: Optional[VirtualDevice.BackingInfo] = None
      profile: list[ProfileSpec] = []
      backing: Optional[BackingSpec] = None
      filterSpec: list[BaseIndependentFilterSpec] = []

   class DiskMoveOptions(Enum):
      moveAllDiskBackingsAndAllowSharing: ClassVar['DiskMoveOptions'] = 'moveAllDiskBackingsAndAllowSharing'
      moveAllDiskBackingsAndDisallowSharing: ClassVar['DiskMoveOptions'] = 'moveAllDiskBackingsAndDisallowSharing'
      moveChildMostDiskBacking: ClassVar['DiskMoveOptions'] = 'moveChildMostDiskBacking'
      createNewChildDiskBacking: ClassVar['DiskMoveOptions'] = 'createNewChildDiskBacking'
      moveAllDiskBackingsAndConsolidate: ClassVar['DiskMoveOptions'] = 'moveAllDiskBackingsAndConsolidate'

   service: Optional[ServiceLocator] = None
   folder: Optional[Folder] = None
   datastore: Optional[Datastore] = None
   diskMoveType: Optional[str] = None
   pool: Optional[ResourcePool] = None
   host: Optional[HostSystem] = None
   disk: list[DiskLocator] = []
   transform: Optional[Transformation] = None
   deviceChange: list[VirtualDeviceSpec] = []
   profile: list[ProfileSpec] = []
   cryptoSpec: Optional[CryptoSpec] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim.event import HostEventArgument
from pyVmomi.vim.event import VmPoweredOffEvent

class VmShutdownOnIsolationEvent(VmPoweredOffEvent):
   class Operation(Enum):
      shutdown: ClassVar['Operation'] = 'shutdown'
      poweredOff: ClassVar['Operation'] = 'poweredOff'

   isolatedHost: HostEventArgument
   shutdownResult: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject
from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import LocalizableMessage

class VsanInternalSystem(ManagedObject):
   class CmmdsQuery(DynamicData):
      type: Optional[str] = None
      uuid: Optional[str] = None
      owner: Optional[str] = None

   class PolicyCost(DynamicData):
      changeDataSize: Optional[long] = None
      currentDataSize: Optional[long] = None
      tempDataSize: Optional[long] = None
      copyDataSize: Optional[long] = None
      changeFlashReadCacheSize: Optional[long] = None
      currentFlashReadCacheSize: Optional[long] = None
      currentDiskSpaceToAddressSpaceRatio: Optional[float] = None
      diskSpaceToAddressSpaceRatio: Optional[float] = None

   class PolicySatisfiability(DynamicData):
      uuid: Optional[str] = None
      isSatisfiable: bool
      reason: Optional[LocalizableMessage] = None
      cost: Optional[PolicyCost] = None

   class PolicyChangeBatch(DynamicData):
      uuid: list[str] = []
      policy: Optional[str] = None

   class NewPolicyBatch(DynamicData):
      size: list[long] = []
      policy: Optional[str] = None

   class VsanPhysicalDiskDiagnosticsResult(DynamicData):
      diskUuid: str
      success: bool
      failureReason: Optional[str] = None

   class DeleteVsanObjectsResult(DynamicData):
      uuid: str
      success: bool
      failureReason: list[LocalizableMessage] = []

   class VsanObjectOperationResult(DynamicData):
      uuid: str
      failureReason: list[LocalizableMessage] = []

   def QueryCmmds(self, queries: list[CmmdsQuery]) -> str: ...
   def QueryPhysicalVsanDisks(self, props: list[str]) -> str: ...
   def QueryVsanObjects(self, uuids: list[str]) -> str: ...
   def QueryObjectsOnPhysicalVsanDisk(self, disks: list[str]) -> str: ...
   def AbdicateDomOwnership(self, uuids: list[str]) -> list[str]: ...
   def QueryVsanStatistics(self, labels: list[str]) -> str: ...
   def ReconfigureDomObject(self, uuid: str, policy: str) -> NoReturn: ...
   def QuerySyncingVsanObjects(self, uuids: list[str]) -> str: ...
   def RunVsanPhysicalDiskDiagnostics(self, disks: list[str]) -> list[VsanPhysicalDiskDiagnosticsResult]: ...
   def GetVsanObjExtAttrs(self, uuids: list[str]) -> str: ...
   def ReconfigurationSatisfiable(self, pcbs: list[PolicyChangeBatch], ignoreSatisfiability: Optional[bool]) -> list[PolicySatisfiability]: ...
   def CanProvisionObjects(self, npbs: list[NewPolicyBatch], ignoreSatisfiability: Optional[bool]) -> list[PolicySatisfiability]: ...
   def DeleteVsanObjects(self, uuids: list[str], force: Optional[bool]) -> list[DeleteVsanObjectsResult]: ...
   def UpgradeVsanObjects(self, uuids: list[str], newVersion: int) -> list[VsanObjectOperationResult]: ...
   def QueryVsanObjectUuidsByFilter(self, uuids: list[str], limit: Optional[int], version: Optional[int]) -> list[str]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.vim import VirtualMachine

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vm import Snapshot

class SnapshotTree(DynamicData):
   snapshot: Snapshot
   vm: VirtualMachine
   name: str
   description: str
   id: int
   createTime: datetime
   state: VirtualMachine.PowerState
   quiesced: bool
   backupManifest: Optional[str] = None
   childSnapshotList: list[SnapshotTree] = []
   replaySupported: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vim import Network
from pyVmomi.vim import SharesInfo

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.dvs import PortConnection

from pyVmomi.vim.vm.device import VirtualDevice

class VirtualEthernetCard(VirtualDevice):
   class NetworkBackingInfo(VirtualDevice.DeviceBackingInfo):
      network: Optional[Network] = None
      inPassthroughMode: Optional[bool] = None

   class LegacyNetworkBackingInfo(VirtualDevice.DeviceBackingInfo):
      pass

   class DistributedVirtualPortBackingInfo(VirtualDevice.BackingInfo):
      port: PortConnection

   class OpaqueNetworkBackingInfo(VirtualDevice.BackingInfo):
      opaqueNetworkId: str
      opaqueNetworkType: str

   class ResourceAllocation(DynamicData):
      reservation: Optional[long] = None
      share: SharesInfo
      limit: Optional[long] = None

   addressType: Optional[str] = None
   macAddress: Optional[str] = None
   wakeOnLanEnabled: Optional[bool] = None
   resourceAllocation: Optional[ResourceAllocation] = None
   externalId: Optional[str] = None
   uptCompatibilityEnabled: Optional[bool] = None
   subnetId: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

class VsanClusterBalancePerDiskInfo(DynamicData):
   uuid: Optional[str] = None
   fullness: long
   variance: long
   fullnessAboveThreshold: long
   dataToMoveB: long
   compFullness: Optional[long] = None
   compVariance: Optional[long] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import HostSystem
from pyVmomi.vim import ManagedEntity

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import DasAdmissionControlInfo

class FailoverHostAdmissionControlInfo(DasAdmissionControlInfo):
   class HostStatus(DynamicData):
      host: HostSystem
      status: ManagedEntity.Status

   hostStatus: list[HostStatus] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import ManagedObject
from pyVmomi.VmomiSupport import long

from pyVmomi.vim import KeyValue
from pyVmomi.vim import ManagedEntity
from pyVmomi.vim import Task

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

class HttpNfcLease(ManagedObject):
   class State(Enum):
      initializing: ClassVar['State'] = 'initializing'
      ready: ClassVar['State'] = 'ready'
      done: ClassVar['State'] = 'done'
      error: ClassVar['State'] = 'error'

   class Mode(Enum):
      pushOrGet: ClassVar['Mode'] = 'pushOrGet'
      pull: ClassVar['Mode'] = 'pull'

   class DatastoreLeaseInfo(DynamicData):
      datastoreKey: str
      hosts: list[HostInfo] = []

   class HostInfo(DynamicData):
      url: str
      sslThumbprint: str

   class Info(DynamicData):
      lease: HttpNfcLease
      entity: ManagedEntity
      deviceUrl: list[DeviceUrl] = []
      totalDiskCapacityInKB: long
      leaseTimeout: int
      hostMap: list[DatastoreLeaseInfo] = []

   class DeviceUrl(DynamicData):
      key: str
      importKey: str
      url: str
      sslThumbprint: str
      sslCertificate: Optional[str] = None
      disk: Optional[bool] = None
      targetId: Optional[str] = None
      datastoreKey: Optional[str] = None
      fileSize: Optional[long] = None

   class ManifestEntry(DynamicData):
      class ChecksumType(Enum):
         sha1: ClassVar['ChecksumType'] = 'sha1'
         sha256: ClassVar['ChecksumType'] = 'sha256'

      key: str
      sha1: str
      checksum: Optional[str] = None
      checksumType: Optional[str] = None
      size: long
      disk: bool
      capacity: Optional[long] = None
      populatedSize: Optional[long] = None

   class SourceFile(DynamicData):
      targetDeviceId: str
      url: str
      memberName: Optional[str] = None
      create: bool
      sslThumbprint: Optional[str] = None
      sslCertificate: Optional[str] = None
      httpHeaders: list[KeyValue] = []
      size: Optional[long] = None

   class Capabilities(DynamicData):
      pullModeSupported: bool
      corsSupported: bool

   class ProbeResult(DynamicData):
      serverAccessible: bool

   @property
   def initializeProgress(self) -> int: ...
   @property
   def transferProgress(self) -> int: ...
   @property
   def mode(self) -> str: ...
   @property
   def capabilities(self) -> Capabilities: ...
   @property
   def info(self) -> Optional[Info]: ...
   @property
   def state(self) -> State: ...
   @property
   def error(self) -> Optional[MethodFault]: ...

   def GetManifest(self) -> list[ManifestEntry]: ...
   def SetManifestChecksumType(self, deviceUrlsToChecksumTypes: list[KeyValue]) -> NoReturn: ...
   def Complete(self) -> NoReturn: ...
   def Abort(self, fault: Optional[MethodFault]) -> NoReturn: ...
   def Progress(self, percent: int) -> NoReturn: ...
   def PullFromUrls(self, files: list[SourceFile]) -> Task: ...
   def ProbeUrls(self, files: list[SourceFile], timeout: Optional[int]) -> list[ProbeResult]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

class HostDiskMappingOption(DynamicData):
   class PartitionOption(DynamicData):
      name: str
      fileSystem: str
      capacityInKb: long

   physicalPartition: list[PartitionOption] = []
   name: str



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class CpuPowerManagementInfo(DynamicData):
   class PolicyType(Enum):
      off: ClassVar['PolicyType'] = 'off'
      staticPolicy: ClassVar['PolicyType'] = 'staticPolicy'
      dynamicPolicy: ClassVar['PolicyType'] = 'dynamicPolicy'

   currentPolicy: Optional[str] = None
   hardwareSupport: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long
from pyVmomi.VmomiSupport import short

from pyVmomi.vim import LatencySensitivity
from pyVmomi.vim import ResourceAllocationInfo

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.encryption import CryptoSpec

from pyVmomi.vim.ext import ManagedByInfo

from pyVmomi.vim.host import CpuIdInfo

from pyVmomi.vim.option import ArrayUpdateSpec
from pyVmomi.vim.option import OptionValue

from pyVmomi.vim.vApp import VmConfigSpec

from pyVmomi.vim.vm import AffinityInfo
from pyVmomi.vim.vm import BootOptions
from pyVmomi.vim.vm import ConsolePreferences
from pyVmomi.vim.vm import DefaultPowerOpInfo
from pyVmomi.vim.vm import FaultToleranceConfigInfo
from pyVmomi.vim.vm import FileInfo
from pyVmomi.vim.vm import FlagInfo
from pyVmomi.vim.vm import GuestMonitoringModeInfo
from pyVmomi.vim.vm import NetworkShaperInfo
from pyVmomi.vim.vm import ProfileSpec
from pyVmomi.vim.vm import ReplicationConfigSpec
from pyVmomi.vim.vm import ScheduledHardwareUpgradeInfo
from pyVmomi.vim.vm import SgxInfo
from pyVmomi.vim.vm import ToolsConfigInfo
from pyVmomi.vim.vm import VcpuConfig
from pyVmomi.vim.vm import VirtualDeviceGroups
from pyVmomi.vim.vm import VirtualDeviceSwap
from pyVmomi.vim.vm import VirtualNuma
from pyVmomi.vim.vm import VirtualPMem

from pyVmomi.vim.vm.device import VirtualDeviceSpec

class ConfigSpec(DynamicData):
   class NpivWwnOp(Enum):
      generate: ClassVar['NpivWwnOp'] = 'generate'
      set: ClassVar['NpivWwnOp'] = 'set'
      remove: ClassVar['NpivWwnOp'] = 'remove'
      extend: ClassVar['NpivWwnOp'] = 'extend'

   class EncryptedFtModes(Enum):
      ftEncryptionDisabled: ClassVar['EncryptedFtModes'] = 'ftEncryptionDisabled'
      ftEncryptionOpportunistic: ClassVar['EncryptedFtModes'] = 'ftEncryptionOpportunistic'
      ftEncryptionRequired: ClassVar['EncryptedFtModes'] = 'ftEncryptionRequired'

   class EncryptedVMotionModes(Enum):
      disabled: ClassVar['EncryptedVMotionModes'] = 'disabled'
      opportunistic: ClassVar['EncryptedVMotionModes'] = 'opportunistic'
      required: ClassVar['EncryptedVMotionModes'] = 'required'

   class CpuIdInfoSpec(ArrayUpdateSpec):
      info: Optional[CpuIdInfo] = None

   changeVersion: Optional[str] = None
   name: Optional[str] = None
   version: Optional[str] = None
   createDate: Optional[datetime] = None
   uuid: Optional[str] = None
   instanceUuid: Optional[str] = None
   npivNodeWorldWideName: list[long] = []
   npivPortWorldWideName: list[long] = []
   npivWorldWideNameType: Optional[str] = None
   npivDesiredNodeWwns: Optional[short] = None
   npivDesiredPortWwns: Optional[short] = None
   npivTemporaryDisabled: Optional[bool] = None
   npivOnNonRdmDisks: Optional[bool] = None
   npivWorldWideNameOp: Optional[str] = None
   locationId: Optional[str] = None
   guestId: Optional[str] = None
   alternateGuestName: Optional[str] = None
   annotation: Optional[str] = None
   files: Optional[FileInfo] = None
   tools: Optional[ToolsConfigInfo] = None
   flags: Optional[FlagInfo] = None
   consolePreferences: Optional[ConsolePreferences] = None
   powerOpInfo: Optional[DefaultPowerOpInfo] = None
   rebootPowerOff: Optional[bool] = None
   numCPUs: Optional[int] = None
   vcpuConfig: list[VcpuConfig] = []
   numCoresPerSocket: Optional[int] = None
   memoryMB: Optional[long] = None
   memoryHotAddEnabled: Optional[bool] = None
   cpuHotAddEnabled: Optional[bool] = None
   cpuHotRemoveEnabled: Optional[bool] = None
   virtualICH7MPresent: Optional[bool] = None
   virtualSMCPresent: Optional[bool] = None
   deviceChange: list[VirtualDeviceSpec] = []
   cpuAllocation: Optional[ResourceAllocationInfo] = None
   memoryAllocation: Optional[ResourceAllocationInfo] = None
   latencySensitivity: Optional[LatencySensitivity] = None
   cpuAffinity: Optional[AffinityInfo] = None
   memoryAffinity: Optional[AffinityInfo] = None
   networkShaper: Optional[NetworkShaperInfo] = None
   cpuFeatureMask: list[CpuIdInfoSpec] = []
   extraConfig: list[OptionValue] = []
   swapPlacement: Optional[str] = None
   bootOptions: Optional[BootOptions] = None
   vAppConfig: Optional[VmConfigSpec] = None
   ftInfo: Optional[FaultToleranceConfigInfo] = None
   repConfig: Optional[ReplicationConfigSpec] = None
   vAppConfigRemoved: Optional[bool] = None
   vAssertsEnabled: Optional[bool] = None
   changeTrackingEnabled: Optional[bool] = None
   firmware: Optional[str] = None
   maxMksConnections: Optional[int] = None
   guestAutoLockEnabled: Optional[bool] = None
   managedBy: Optional[ManagedByInfo] = None
   memoryReservationLockedToMax: Optional[bool] = None
   nestedHVEnabled: Optional[bool] = None
   vPMCEnabled: Optional[bool] = None
   scheduledHardwareUpgradeInfo: Optional[ScheduledHardwareUpgradeInfo] = None
   vmProfile: list[ProfileSpec] = []
   messageBusTunnelEnabled: Optional[bool] = None
   crypto: Optional[CryptoSpec] = None
   migrateEncryption: Optional[str] = None
   sgxInfo: Optional[SgxInfo] = None
   ftEncryptionMode: Optional[str] = None
   guestMonitoringModeInfo: Optional[GuestMonitoringModeInfo] = None
   sevEnabled: Optional[bool] = None
   virtualNuma: Optional[VirtualNuma] = None
   motherboardLayout: Optional[str] = None
   pmemFailoverEnabled: Optional[bool] = None
   vmxStatsCollectionEnabled: Optional[bool] = None
   vmOpNotificationToAppEnabled: Optional[bool] = None
   vmOpNotificationTimeout: Optional[long] = None
   deviceSwap: Optional[VirtualDeviceSwap] = None
   simultaneousThreads: Optional[int] = None
   pmem: Optional[VirtualPMem] = None
   deviceGroups: Optional[VirtualDeviceGroups] = None
   fixedPassthruHotPlugEnabled: Optional[bool] = None
   metroFtEnabled: Optional[bool] = None
   metroFtHostGroup: Optional[str] = None
   tdxEnabled: Optional[bool] = None
   sevSnpEnabled: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.option import IntOption

from pyVmomi.vim.vm.device import VirtualControllerOption

class VirtualPCIControllerOption(VirtualControllerOption):
   numSCSIControllers: IntOption
   numEthernetCards: IntOption
   numVideoCards: IntOption
   numSoundCards: IntOption
   numVmiRoms: IntOption
   numVmciDevices: IntOption
   numPCIPassthroughDevices: IntOption
   numSasSCSIControllers: IntOption
   numVmxnet3EthernetCards: IntOption
   numParaVirtualSCSIControllers: IntOption
   numSATAControllers: IntOption
   numNVMEControllers: Optional[IntOption] = None
   numVmxnet3VrdmaEthernetCards: Optional[IntOption] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import CpuIdInfo

from pyVmomi.vim.option import BoolOption
from pyVmomi.vim.option import IntOption

class GuestOsDescriptor(DynamicData):
   class GuestOsFamily(Enum):
      windowsGuest: ClassVar['GuestOsFamily'] = 'windowsGuest'
      linuxGuest: ClassVar['GuestOsFamily'] = 'linuxGuest'
      netwareGuest: ClassVar['GuestOsFamily'] = 'netwareGuest'
      solarisGuest: ClassVar['GuestOsFamily'] = 'solarisGuest'
      darwinGuestFamily: ClassVar['GuestOsFamily'] = 'darwinGuestFamily'
      otherGuestFamily: ClassVar['GuestOsFamily'] = 'otherGuestFamily'

   class GuestOsIdentifier(Enum):
      dosGuest: ClassVar['GuestOsIdentifier'] = 'dosGuest'
      win31Guest: ClassVar['GuestOsIdentifier'] = 'win31Guest'
      win95Guest: ClassVar['GuestOsIdentifier'] = 'win95Guest'
      win98Guest: ClassVar['GuestOsIdentifier'] = 'win98Guest'
      winMeGuest: ClassVar['GuestOsIdentifier'] = 'winMeGuest'
      winNTGuest: ClassVar['GuestOsIdentifier'] = 'winNTGuest'
      win2000ProGuest: ClassVar['GuestOsIdentifier'] = 'win2000ProGuest'
      win2000ServGuest: ClassVar['GuestOsIdentifier'] = 'win2000ServGuest'
      win2000AdvServGuest: ClassVar['GuestOsIdentifier'] = 'win2000AdvServGuest'
      winXPHomeGuest: ClassVar['GuestOsIdentifier'] = 'winXPHomeGuest'
      winXPProGuest: ClassVar['GuestOsIdentifier'] = 'winXPProGuest'
      winXPPro64Guest: ClassVar['GuestOsIdentifier'] = 'winXPPro64Guest'
      winNetWebGuest: ClassVar['GuestOsIdentifier'] = 'winNetWebGuest'
      winNetStandardGuest: ClassVar['GuestOsIdentifier'] = 'winNetStandardGuest'
      winNetEnterpriseGuest: ClassVar['GuestOsIdentifier'] = 'winNetEnterpriseGuest'
      winNetDatacenterGuest: ClassVar['GuestOsIdentifier'] = 'winNetDatacenterGuest'
      winNetBusinessGuest: ClassVar['GuestOsIdentifier'] = 'winNetBusinessGuest'
      winNetStandard64Guest: ClassVar['GuestOsIdentifier'] = 'winNetStandard64Guest'
      winNetEnterprise64Guest: ClassVar['GuestOsIdentifier'] = 'winNetEnterprise64Guest'
      winLonghornGuest: ClassVar['GuestOsIdentifier'] = 'winLonghornGuest'
      winLonghorn64Guest: ClassVar['GuestOsIdentifier'] = 'winLonghorn64Guest'
      winNetDatacenter64Guest: ClassVar['GuestOsIdentifier'] = 'winNetDatacenter64Guest'
      winVistaGuest: ClassVar['GuestOsIdentifier'] = 'winVistaGuest'
      winVista64Guest: ClassVar['GuestOsIdentifier'] = 'winVista64Guest'
      windows7Guest: ClassVar['GuestOsIdentifier'] = 'windows7Guest'
      windows7_64Guest: ClassVar['GuestOsIdentifier'] = 'windows7_64Guest'
      windows7Server64Guest: ClassVar['GuestOsIdentifier'] = 'windows7Server64Guest'
      windows8Guest: ClassVar['GuestOsIdentifier'] = 'windows8Guest'
      windows8_64Guest: ClassVar['GuestOsIdentifier'] = 'windows8_64Guest'
      windows8Server64Guest: ClassVar['GuestOsIdentifier'] = 'windows8Server64Guest'
      windows9Guest: ClassVar['GuestOsIdentifier'] = 'windows9Guest'
      windows9_64Guest: ClassVar['GuestOsIdentifier'] = 'windows9_64Guest'
      windows9Server64Guest: ClassVar['GuestOsIdentifier'] = 'windows9Server64Guest'
      windows11_64Guest: ClassVar['GuestOsIdentifier'] = 'windows11_64Guest'
      windows12_64Guest: ClassVar['GuestOsIdentifier'] = 'windows12_64Guest'
      windowsHyperVGuest: ClassVar['GuestOsIdentifier'] = 'windowsHyperVGuest'
      windows2019srv_64Guest: ClassVar['GuestOsIdentifier'] = 'windows2019srv_64Guest'
      windows2019srvNext_64Guest: ClassVar['GuestOsIdentifier'] = 'windows2019srvNext_64Guest'
      windows2022srvNext_64Guest: ClassVar['GuestOsIdentifier'] = 'windows2022srvNext_64Guest'
      freebsdGuest: ClassVar['GuestOsIdentifier'] = 'freebsdGuest'
      freebsd64Guest: ClassVar['GuestOsIdentifier'] = 'freebsd64Guest'
      freebsd11Guest: ClassVar['GuestOsIdentifier'] = 'freebsd11Guest'
      freebsd11_64Guest: ClassVar['GuestOsIdentifier'] = 'freebsd11_64Guest'
      freebsd12Guest: ClassVar['GuestOsIdentifier'] = 'freebsd12Guest'
      freebsd12_64Guest: ClassVar['GuestOsIdentifier'] = 'freebsd12_64Guest'
      freebsd13Guest: ClassVar['GuestOsIdentifier'] = 'freebsd13Guest'
      freebsd13_64Guest: ClassVar['GuestOsIdentifier'] = 'freebsd13_64Guest'
      freebsd14Guest: ClassVar['GuestOsIdentifier'] = 'freebsd14Guest'
      freebsd14_64Guest: ClassVar['GuestOsIdentifier'] = 'freebsd14_64Guest'
      freebsd15Guest: ClassVar['GuestOsIdentifier'] = 'freebsd15Guest'
      freebsd15_64Guest: ClassVar['GuestOsIdentifier'] = 'freebsd15_64Guest'
      redhatGuest: ClassVar['GuestOsIdentifier'] = 'redhatGuest'
      rhel2Guest: ClassVar['GuestOsIdentifier'] = 'rhel2Guest'
      rhel3Guest: ClassVar['GuestOsIdentifier'] = 'rhel3Guest'
      rhel3_64Guest: ClassVar['GuestOsIdentifier'] = 'rhel3_64Guest'
      rhel4Guest: ClassVar['GuestOsIdentifier'] = 'rhel4Guest'
      rhel4_64Guest: ClassVar['GuestOsIdentifier'] = 'rhel4_64Guest'
      rhel5Guest: ClassVar['GuestOsIdentifier'] = 'rhel5Guest'
      rhel5_64Guest: ClassVar['GuestOsIdentifier'] = 'rhel5_64Guest'
      rhel6Guest: ClassVar['GuestOsIdentifier'] = 'rhel6Guest'
      rhel6_64Guest: ClassVar['GuestOsIdentifier'] = 'rhel6_64Guest'
      rhel7Guest: ClassVar['GuestOsIdentifier'] = 'rhel7Guest'
      rhel7_64Guest: ClassVar['GuestOsIdentifier'] = 'rhel7_64Guest'
      rhel8_64Guest: ClassVar['GuestOsIdentifier'] = 'rhel8_64Guest'
      rhel9_64Guest: ClassVar['GuestOsIdentifier'] = 'rhel9_64Guest'
      rhel10_64Guest: ClassVar['GuestOsIdentifier'] = 'rhel10_64Guest'
      centosGuest: ClassVar['GuestOsIdentifier'] = 'centosGuest'
      centos64Guest: ClassVar['GuestOsIdentifier'] = 'centos64Guest'
      centos6Guest: ClassVar['GuestOsIdentifier'] = 'centos6Guest'
      centos6_64Guest: ClassVar['GuestOsIdentifier'] = 'centos6_64Guest'
      centos7Guest: ClassVar['GuestOsIdentifier'] = 'centos7Guest'
      centos7_64Guest: ClassVar['GuestOsIdentifier'] = 'centos7_64Guest'
      centos8_64Guest: ClassVar['GuestOsIdentifier'] = 'centos8_64Guest'
      centos9_64Guest: ClassVar['GuestOsIdentifier'] = 'centos9_64Guest'
      oracleLinuxGuest: ClassVar['GuestOsIdentifier'] = 'oracleLinuxGuest'
      oracleLinux64Guest: ClassVar['GuestOsIdentifier'] = 'oracleLinux64Guest'
      oracleLinux6Guest: ClassVar['GuestOsIdentifier'] = 'oracleLinux6Guest'
      oracleLinux6_64Guest: ClassVar['GuestOsIdentifier'] = 'oracleLinux6_64Guest'
      oracleLinux7Guest: ClassVar['GuestOsIdentifier'] = 'oracleLinux7Guest'
      oracleLinux7_64Guest: ClassVar['GuestOsIdentifier'] = 'oracleLinux7_64Guest'
      oracleLinux8_64Guest: ClassVar['GuestOsIdentifier'] = 'oracleLinux8_64Guest'
      oracleLinux9_64Guest: ClassVar['GuestOsIdentifier'] = 'oracleLinux9_64Guest'
      oracleLinux10_64Guest: ClassVar['GuestOsIdentifier'] = 'oracleLinux10_64Guest'
      suseGuest: ClassVar['GuestOsIdentifier'] = 'suseGuest'
      suse64Guest: ClassVar['GuestOsIdentifier'] = 'suse64Guest'
      slesGuest: ClassVar['GuestOsIdentifier'] = 'slesGuest'
      sles64Guest: ClassVar['GuestOsIdentifier'] = 'sles64Guest'
      sles10Guest: ClassVar['GuestOsIdentifier'] = 'sles10Guest'
      sles10_64Guest: ClassVar['GuestOsIdentifier'] = 'sles10_64Guest'
      sles11Guest: ClassVar['GuestOsIdentifier'] = 'sles11Guest'
      sles11_64Guest: ClassVar['GuestOsIdentifier'] = 'sles11_64Guest'
      sles12Guest: ClassVar['GuestOsIdentifier'] = 'sles12Guest'
      sles12_64Guest: ClassVar['GuestOsIdentifier'] = 'sles12_64Guest'
      sles15_64Guest: ClassVar['GuestOsIdentifier'] = 'sles15_64Guest'
      sles16_64Guest: ClassVar['GuestOsIdentifier'] = 'sles16_64Guest'
      nld9Guest: ClassVar['GuestOsIdentifier'] = 'nld9Guest'
      oesGuest: ClassVar['GuestOsIdentifier'] = 'oesGuest'
      sjdsGuest: ClassVar['GuestOsIdentifier'] = 'sjdsGuest'
      mandrakeGuest: ClassVar['GuestOsIdentifier'] = 'mandrakeGuest'
      mandrivaGuest: ClassVar['GuestOsIdentifier'] = 'mandrivaGuest'
      mandriva64Guest: ClassVar['GuestOsIdentifier'] = 'mandriva64Guest'
      turboLinuxGuest: ClassVar['GuestOsIdentifier'] = 'turboLinuxGuest'
      turboLinux64Guest: ClassVar['GuestOsIdentifier'] = 'turboLinux64Guest'
      ubuntuGuest: ClassVar['GuestOsIdentifier'] = 'ubuntuGuest'
      ubuntu64Guest: ClassVar['GuestOsIdentifier'] = 'ubuntu64Guest'
      debian4Guest: ClassVar['GuestOsIdentifier'] = 'debian4Guest'
      debian4_64Guest: ClassVar['GuestOsIdentifier'] = 'debian4_64Guest'
      debian5Guest: ClassVar['GuestOsIdentifier'] = 'debian5Guest'
      debian5_64Guest: ClassVar['GuestOsIdentifier'] = 'debian5_64Guest'
      debian6Guest: ClassVar['GuestOsIdentifier'] = 'debian6Guest'
      debian6_64Guest: ClassVar['GuestOsIdentifier'] = 'debian6_64Guest'
      debian7Guest: ClassVar['GuestOsIdentifier'] = 'debian7Guest'
      debian7_64Guest: ClassVar['GuestOsIdentifier'] = 'debian7_64Guest'
      debian8Guest: ClassVar['GuestOsIdentifier'] = 'debian8Guest'
      debian8_64Guest: ClassVar['GuestOsIdentifier'] = 'debian8_64Guest'
      debian9Guest: ClassVar['GuestOsIdentifier'] = 'debian9Guest'
      debian9_64Guest: ClassVar['GuestOsIdentifier'] = 'debian9_64Guest'
      debian10Guest: ClassVar['GuestOsIdentifier'] = 'debian10Guest'
      debian10_64Guest: ClassVar['GuestOsIdentifier'] = 'debian10_64Guest'
      debian11Guest: ClassVar['GuestOsIdentifier'] = 'debian11Guest'
      debian11_64Guest: ClassVar['GuestOsIdentifier'] = 'debian11_64Guest'
      debian12Guest: ClassVar['GuestOsIdentifier'] = 'debian12Guest'
      debian12_64Guest: ClassVar['GuestOsIdentifier'] = 'debian12_64Guest'
      debian13Guest: ClassVar['GuestOsIdentifier'] = 'debian13Guest'
      debian13_64Guest: ClassVar['GuestOsIdentifier'] = 'debian13_64Guest'
      asianux3Guest: ClassVar['GuestOsIdentifier'] = 'asianux3Guest'
      asianux3_64Guest: ClassVar['GuestOsIdentifier'] = 'asianux3_64Guest'
      asianux4Guest: ClassVar['GuestOsIdentifier'] = 'asianux4Guest'
      asianux4_64Guest: ClassVar['GuestOsIdentifier'] = 'asianux4_64Guest'
      asianux5_64Guest: ClassVar['GuestOsIdentifier'] = 'asianux5_64Guest'
      asianux7_64Guest: ClassVar['GuestOsIdentifier'] = 'asianux7_64Guest'
      asianux8_64Guest: ClassVar['GuestOsIdentifier'] = 'asianux8_64Guest'
      asianux9_64Guest: ClassVar['GuestOsIdentifier'] = 'asianux9_64Guest'
      miraclelinux_64Guest: ClassVar['GuestOsIdentifier'] = 'miraclelinux_64Guest'
      pardus_64Guest: ClassVar['GuestOsIdentifier'] = 'pardus_64Guest'
      opensuseGuest: ClassVar['GuestOsIdentifier'] = 'opensuseGuest'
      opensuse64Guest: ClassVar['GuestOsIdentifier'] = 'opensuse64Guest'
      fedoraGuest: ClassVar['GuestOsIdentifier'] = 'fedoraGuest'
      fedora64Guest: ClassVar['GuestOsIdentifier'] = 'fedora64Guest'
      coreos64Guest: ClassVar['GuestOsIdentifier'] = 'coreos64Guest'
      vmwarePhoton64Guest: ClassVar['GuestOsIdentifier'] = 'vmwarePhoton64Guest'
      other24xLinuxGuest: ClassVar['GuestOsIdentifier'] = 'other24xLinuxGuest'
      other26xLinuxGuest: ClassVar['GuestOsIdentifier'] = 'other26xLinuxGuest'
      otherLinuxGuest: ClassVar['GuestOsIdentifier'] = 'otherLinuxGuest'
      other3xLinuxGuest: ClassVar['GuestOsIdentifier'] = 'other3xLinuxGuest'
      other4xLinuxGuest: ClassVar['GuestOsIdentifier'] = 'other4xLinuxGuest'
      other5xLinuxGuest: ClassVar['GuestOsIdentifier'] = 'other5xLinuxGuest'
      other6xLinuxGuest: ClassVar['GuestOsIdentifier'] = 'other6xLinuxGuest'
      other7xLinuxGuest: ClassVar['GuestOsIdentifier'] = 'other7xLinuxGuest'
      genericLinuxGuest: ClassVar['GuestOsIdentifier'] = 'genericLinuxGuest'
      other24xLinux64Guest: ClassVar['GuestOsIdentifier'] = 'other24xLinux64Guest'
      other26xLinux64Guest: ClassVar['GuestOsIdentifier'] = 'other26xLinux64Guest'
      other3xLinux64Guest: ClassVar['GuestOsIdentifier'] = 'other3xLinux64Guest'
      other4xLinux64Guest: ClassVar['GuestOsIdentifier'] = 'other4xLinux64Guest'
      other5xLinux64Guest: ClassVar['GuestOsIdentifier'] = 'other5xLinux64Guest'
      other6xLinux64Guest: ClassVar['GuestOsIdentifier'] = 'other6xLinux64Guest'
      other7xLinux64Guest: ClassVar['GuestOsIdentifier'] = 'other7xLinux64Guest'
      otherLinux64Guest: ClassVar['GuestOsIdentifier'] = 'otherLinux64Guest'
      solaris6Guest: ClassVar['GuestOsIdentifier'] = 'solaris6Guest'
      solaris7Guest: ClassVar['GuestOsIdentifier'] = 'solaris7Guest'
      solaris8Guest: ClassVar['GuestOsIdentifier'] = 'solaris8Guest'
      solaris9Guest: ClassVar['GuestOsIdentifier'] = 'solaris9Guest'
      solaris10Guest: ClassVar['GuestOsIdentifier'] = 'solaris10Guest'
      solaris10_64Guest: ClassVar['GuestOsIdentifier'] = 'solaris10_64Guest'
      solaris11_64Guest: ClassVar['GuestOsIdentifier'] = 'solaris11_64Guest'
      fusionos_64Guest: ClassVar['GuestOsIdentifier'] = 'fusionos_64Guest'
      prolinux_64Guest: ClassVar['GuestOsIdentifier'] = 'prolinux_64Guest'
      kylinlinux_64Guest: ClassVar['GuestOsIdentifier'] = 'kylinlinux_64Guest'
      os2Guest: ClassVar['GuestOsIdentifier'] = 'os2Guest'
      eComStationGuest: ClassVar['GuestOsIdentifier'] = 'eComStationGuest'
      eComStation2Guest: ClassVar['GuestOsIdentifier'] = 'eComStation2Guest'
      netware4Guest: ClassVar['GuestOsIdentifier'] = 'netware4Guest'
      netware5Guest: ClassVar['GuestOsIdentifier'] = 'netware5Guest'
      netware6Guest: ClassVar['GuestOsIdentifier'] = 'netware6Guest'
      openServer5Guest: ClassVar['GuestOsIdentifier'] = 'openServer5Guest'
      openServer6Guest: ClassVar['GuestOsIdentifier'] = 'openServer6Guest'
      unixWare7Guest: ClassVar['GuestOsIdentifier'] = 'unixWare7Guest'
      darwinGuest: ClassVar['GuestOsIdentifier'] = 'darwinGuest'
      darwin64Guest: ClassVar['GuestOsIdentifier'] = 'darwin64Guest'
      darwin10Guest: ClassVar['GuestOsIdentifier'] = 'darwin10Guest'
      darwin10_64Guest: ClassVar['GuestOsIdentifier'] = 'darwin10_64Guest'
      darwin11Guest: ClassVar['GuestOsIdentifier'] = 'darwin11Guest'
      darwin11_64Guest: ClassVar['GuestOsIdentifier'] = 'darwin11_64Guest'
      darwin12_64Guest: ClassVar['GuestOsIdentifier'] = 'darwin12_64Guest'
      darwin13_64Guest: ClassVar['GuestOsIdentifier'] = 'darwin13_64Guest'
      darwin14_64Guest: ClassVar['GuestOsIdentifier'] = 'darwin14_64Guest'
      darwin15_64Guest: ClassVar['GuestOsIdentifier'] = 'darwin15_64Guest'
      darwin16_64Guest: ClassVar['GuestOsIdentifier'] = 'darwin16_64Guest'
      darwin17_64Guest: ClassVar['GuestOsIdentifier'] = 'darwin17_64Guest'
      darwin18_64Guest: ClassVar['GuestOsIdentifier'] = 'darwin18_64Guest'
      darwin19_64Guest: ClassVar['GuestOsIdentifier'] = 'darwin19_64Guest'
      darwin20_64Guest: ClassVar['GuestOsIdentifier'] = 'darwin20_64Guest'
      darwin21_64Guest: ClassVar['GuestOsIdentifier'] = 'darwin21_64Guest'
      darwin22_64Guest: ClassVar['GuestOsIdentifier'] = 'darwin22_64Guest'
      darwin23_64Guest: ClassVar['GuestOsIdentifier'] = 'darwin23_64Guest'
      vmkernelGuest: ClassVar['GuestOsIdentifier'] = 'vmkernelGuest'
      vmkernel5Guest: ClassVar['GuestOsIdentifier'] = 'vmkernel5Guest'
      vmkernel6Guest: ClassVar['GuestOsIdentifier'] = 'vmkernel6Guest'
      vmkernel65Guest: ClassVar['GuestOsIdentifier'] = 'vmkernel65Guest'
      vmkernel7Guest: ClassVar['GuestOsIdentifier'] = 'vmkernel7Guest'
      vmkernel8Guest: ClassVar['GuestOsIdentifier'] = 'vmkernel8Guest'
      vmkernel9Guest: ClassVar['GuestOsIdentifier'] = 'vmkernel9Guest'
      amazonlinux2_64Guest: ClassVar['GuestOsIdentifier'] = 'amazonlinux2_64Guest'
      amazonlinux3_64Guest: ClassVar['GuestOsIdentifier'] = 'amazonlinux3_64Guest'
      crxPod1Guest: ClassVar['GuestOsIdentifier'] = 'crxPod1Guest'
      crxSys1Guest: ClassVar['GuestOsIdentifier'] = 'crxSys1Guest'
      rockylinux_64Guest: ClassVar['GuestOsIdentifier'] = 'rockylinux_64Guest'
      almalinux_64Guest: ClassVar['GuestOsIdentifier'] = 'almalinux_64Guest'
      otherGuest: ClassVar['GuestOsIdentifier'] = 'otherGuest'
      otherGuest64: ClassVar['GuestOsIdentifier'] = 'otherGuest64'

   class FirmwareType(Enum):
      bios: ClassVar['FirmwareType'] = 'bios'
      efi: ClassVar['FirmwareType'] = 'efi'
      csm: ClassVar['FirmwareType'] = 'csm'

   class SupportLevel(Enum):
      experimental: ClassVar['SupportLevel'] = 'experimental'
      legacy: ClassVar['SupportLevel'] = 'legacy'
      terminated: ClassVar['SupportLevel'] = 'terminated'
      supported: ClassVar['SupportLevel'] = 'supported'
      unsupported: ClassVar['SupportLevel'] = 'unsupported'
      deprecated: ClassVar['SupportLevel'] = 'deprecated'
      techPreview: ClassVar['SupportLevel'] = 'techPreview'

   id: str
   family: str
   fullName: str
   supportedMaxCPUs: int
   numSupportedPhysicalSockets: int
   numSupportedCoresPerSocket: int
   supportedMinMemMB: int
   supportedMaxMemMB: int
   recommendedMemMB: int
   recommendedColorDepth: int
   supportedDiskControllerList: list[type] = []
   recommendedSCSIController: Optional[type] = None
   recommendedDiskController: type
   supportedNumDisks: int
   recommendedDiskSizeMB: int
   recommendedCdromController: type
   supportedEthernetCard: list[type] = []
   recommendedEthernetCard: Optional[type] = None
   supportsSlaveDisk: Optional[bool] = None
   cpuFeatureMask: list[CpuIdInfo] = []
   smcRequired: bool
   supportsWakeOnLan: bool
   supportsVMI: bool
   supportsMemoryHotAdd: bool
   supportsCpuHotAdd: bool
   supportsCpuHotRemove: bool
   supportedFirmware: list[str] = []
   recommendedFirmware: str
   supportedUSBControllerList: list[type] = []
   recommendedUSBController: Optional[type] = None
   supports3D: bool
   recommended3D: bool
   smcRecommended: bool
   ich7mRecommended: bool
   usbRecommended: bool
   supportLevel: str
   supportedForCreate: bool
   vRAMSizeInKB: IntOption
   numSupportedFloppyDevices: int
   wakeOnLanEthernetCard: list[type] = []
   supportsPvscsiControllerForBoot: bool
   diskUuidEnabled: bool
   supportsHotPlugPCI: bool
   supportsSecureBoot: Optional[bool] = None
   defaultSecureBoot: Optional[bool] = None
   persistentMemorySupported: Optional[bool] = None
   supportedMinPersistentMemoryMB: Optional[long] = None
   supportedMaxPersistentMemoryMB: Optional[long] = None
   recommendedPersistentMemoryMB: Optional[long] = None
   persistentMemoryHotAddSupported: Optional[bool] = None
   persistentMemoryHotRemoveSupported: Optional[bool] = None
   persistentMemoryColdGrowthSupported: Optional[bool] = None
   persistentMemoryColdGrowthGranularityMB: Optional[long] = None
   persistentMemoryHotGrowthSupported: Optional[bool] = None
   persistentMemoryHotGrowthGranularityMB: Optional[long] = None
   numRecommendedPhysicalSockets: Optional[int] = None
   numRecommendedCoresPerSocket: Optional[int] = None
   vvtdSupported: Optional[BoolOption] = None
   vbsSupported: Optional[BoolOption] = None
   vsgxSupported: Optional[BoolOption] = None
   vsgxRemoteAttestationSupported: Optional[bool] = None
   supportsTPM20: Optional[bool] = None
   recommendedTPM20: Optional[bool] = None
   vwdtSupported: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim.event import HostEvent

class HostDisconnectedEvent(HostEvent):
   class ReasonCode(Enum):
      sslThumbprintVerifyFailed: ClassVar['ReasonCode'] = 'sslThumbprintVerifyFailed'
      licenseExpired: ClassVar['ReasonCode'] = 'licenseExpired'
      agentUpgrade: ClassVar['ReasonCode'] = 'agentUpgrade'
      userRequest: ClassVar['ReasonCode'] = 'userRequest'
      insufficientLicenses: ClassVar['ReasonCode'] = 'insufficientLicenses'
      agentOutOfDate: ClassVar['ReasonCode'] = 'agentOutOfDate'
      passwordDecryptFailure: ClassVar['ReasonCode'] = 'passwordDecryptFailure'
      unknown: ClassVar['ReasonCode'] = 'unknown'
      vcVRAMCapacityExceeded: ClassVar['ReasonCode'] = 'vcVRAMCapacityExceeded'

   reason: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import ComputeResource
from pyVmomi.vim import Task

from pyVmomi.vim.cluster import VsanObjIdentityQuerySpec
from pyVmomi.vim.cluster import VsanObjectIdentityAndHealth
from pyVmomi.vim.cluster import VsanObjectInformation
from pyVmomi.vim.cluster import VsanObjectQuerySpec
from pyVmomi.vim.cluster import VsanSyncingObjectFilter

from pyVmomi.vim.vm import ProfileSpec

from pyVmomi.vim.vsan.host import VsanSyncingObjectQueryResult

class VsanObjectSystem(ManagedObject):
   def SetVsanObjectPolicy(self, cluster: Optional[ComputeResource], vsanObjectUuid: str, profile: Optional[ProfileSpec]) -> bool: ...
   def QueryVsanObjectInformation(self, cluster: Optional[ComputeResource], vsanObjectQuerySpecs: list[VsanObjectQuerySpec]) -> list[VsanObjectInformation]: ...
   def QueryObjectIdentities(self, cluster: Optional[ComputeResource], objUuids: list[str], objTypes: list[str], includeHealth: Optional[bool], includeObjIdentity: Optional[bool], includeSpaceSummary: Optional[bool], extraQuerySpec: Optional[VsanObjIdentityQuerySpec]) -> Optional[VsanObjectIdentityAndHealth]: ...
   def DeleteObjects(self, cluster: Optional[ComputeResource], objUuids: list[str], force: Optional[bool]) -> Task: ...
   def QueryInaccessibleVmSwapObjects(self, cluster: Optional[ComputeResource]) -> list[str]: ...
   def QuerySyncingVsanObjectsSummary(self, cluster: ComputeResource, syncingObjectFilter: Optional[VsanSyncingObjectFilter]) -> VsanSyncingObjectQueryResult: ...
   def RelayoutObjects(self, cluster: ComputeResource) -> Task: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class VsanPerfThreshold(DynamicData):
   class VsanPerfThresholdDirectionType(Enum):
      upper: ClassVar['VsanPerfThresholdDirectionType'] = 'upper'
      lower: ClassVar['VsanPerfThresholdDirectionType'] = 'lower'
      VsanPerfThresholdDirectionType_Unknown: ClassVar['VsanPerfThresholdDirectionType'] = 'VsanPerfThresholdDirectionType_Unknown'

   direction: str
   yellow: Optional[str] = None
   red: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class KmipServerInfo(DynamicData):
   name: str
   address: str
   port: int
   proxyAddress: Optional[str] = None
   proxyPort: Optional[int] = None
   reconnect: Optional[int] = None
   protocol: Optional[str] = None
   nbio: Optional[int] = None
   timeout: Optional[int] = None
   userName: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import Network

from pyVmomi.vim.fault import VmConfigFault

class CannotUseNetwork(VmConfigFault):
   class Reason(Enum):
      NetworkReservationNotSupported: ClassVar['Reason'] = 'NetworkReservationNotSupported'
      MismatchedNetworkPolicies: ClassVar['Reason'] = 'MismatchedNetworkPolicies'
      MismatchedDvsVersionOrVendor: ClassVar['Reason'] = 'MismatchedDvsVersionOrVendor'
      VMotionToUnsupportedNetworkType: ClassVar['Reason'] = 'VMotionToUnsupportedNetworkType'
      NetworkUnderMaintenance: ClassVar['Reason'] = 'NetworkUnderMaintenance'
      MismatchedEnsMode: ClassVar['Reason'] = 'MismatchedEnsMode'
      MismatchedRealTimeDvs: ClassVar['Reason'] = 'MismatchedRealTimeDvs'

   device: str
   backing: str
   connected: bool
   reason: str
   network: Optional[Network] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.eam import Agent
from pyVmomi.eam import EamObject

from pyVmomi.vim import ComputeResource
from pyVmomi.vim import Datacenter
from pyVmomi.vim import Datastore
from pyVmomi.vim import Folder
from pyVmomi.vim import Network
from pyVmomi.vim import ResourcePool
from pyVmomi.vim import VirtualMachine

from pyVmomi.vmodl import DynamicData

from pyVmomi.eam.issue import Issue

from pyVmomi.vim.vApp import IpPool

class Agency(EamObject):
   class VMResourcePool(DynamicData):
      resourcePoolId: ResourcePool
      computeResourceId: ComputeResource

   class VMFolder(DynamicData):
      folderId: Folder
      datacenterId: Datacenter

   class ConfigInfo(DynamicData):
      agentConfig: list[Agent.ConfigInfo] = []
      scope: Optional[Scope] = None
      manuallyMarkAgentVmAvailableAfterProvisioning: Optional[bool] = None
      manuallyMarkAgentVmAvailableAfterPowerOn: Optional[bool] = None
      optimizedDeploymentEnabled: Optional[bool] = None
      agentName: Optional[str] = None
      agencyName: Optional[str] = None
      useUuidVmName: Optional[bool] = None
      manuallyProvisioned: Optional[bool] = None
      manuallyMonitored: Optional[bool] = None
      bypassVumEnabled: Optional[bool] = None
      agentVmNetwork: list[Network] = []
      agentVmDatastore: list[Datastore] = []
      preferHostConfiguration: Optional[bool] = None
      ipPool: Optional[IpPool] = None
      resourcePools: list[VMResourcePool] = []
      folders: list[VMFolder] = []

   class Scope(DynamicData):
      pass

   class ComputeResourceScope(Scope):
      computeResource: list[ComputeResource] = []

   @property
   def solutionId(self) -> str: ...
   @property
   def owner(self) -> Optional[str]: ...
   @property
   def config(self) -> ConfigInfo: ...
   @property
   def runtime(self) -> EamObject.RuntimeInfo: ...
   @property
   def agent(self) -> list[Agent]: ...

   def QuerySolutionId(self) -> str: ...
   def QueryConfig(self) -> ConfigInfo: ...
   def Update(self, config: ConfigInfo) -> NoReturn: ...
   def QueryRuntime(self) -> EamObject.RuntimeInfo: ...
   def QueryAgent(self) -> list[Agent]: ...
   def RegisterAgentVm(self, agentVm: VirtualMachine) -> Agent: ...
   def UnregisterAgentVm(self, agentVm: VirtualMachine) -> NoReturn: ...
   def Enable(self) -> NoReturn: ...
   def Disable(self) -> NoReturn: ...
   def Uninstall(self) -> NoReturn: ...
   def DestroyAgency(self) -> NoReturn: ...
   def AddIssue(self, issue: Issue) -> Issue: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import ComputeResource

from pyVmomi.vim.cluster import QueryVsanManagedStorageSpaceUsageSpec
from pyVmomi.vim.cluster import VsanEntitySpaceUsage
from pyVmomi.vim.cluster import VsanSpaceQuerySpec
from pyVmomi.vim.cluster import VsanSpaceUsage
from pyVmomi.vim.cluster import VsanSpaceUsageWithDatastoreType

from pyVmomi.vim.vm import ProfileSpec

class VsanSpaceReportSystem(ManagedObject):
   def QuerySpaceUsage(self, cluster: ComputeResource, storagePolicies: list[ProfileSpec], whatifCapacityOnly: Optional[bool]) -> VsanSpaceUsage: ...
   def QueryVsanManagedStorageSpaceUsage(self, cluster: ComputeResource, querySpec: QueryVsanManagedStorageSpaceUsageSpec) -> list[VsanSpaceUsageWithDatastoreType]: ...
   def QueryEntitySpaceUsage(self, cluster: ComputeResource, querySpec: VsanSpaceQuerySpec) -> list[VsanEntitySpaceUsage]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import Task

from pyVmomi.vim.host import MaintenanceSpec

from pyVmomi.vim.vsan.host import AbortWipeDiskStatus
from pyVmomi.vim.vsan.host import AboutInfoEx
from pyVmomi.vim.vsan.host import ClusterStatus
from pyVmomi.vim.vsan.host import DiskMapping
from pyVmomi.vim.vsan.host import DrsStats
from pyVmomi.vim.vsan.host import RuntimeStats
from pyVmomi.vim.vsan.host import VsanSyncingObjectQueryResult
from pyVmomi.vim.vsan.host import VsanWhatIfEvacResult
from pyVmomi.vim.vsan.host import WipeDiskStatus

class VsanSystemEx(ManagedObject):
   def QueryWhatIfEvacuationResult(self, evacEntityUuid: str) -> VsanWhatIfEvacResult: ...
   def GetRuntimeStats(self, stats: list[str], clusterUuid: Optional[str]) -> RuntimeStats: ...
   def GetAboutInfoEx(self) -> AboutInfoEx: ...
   def QuerySyncingVsanObjects(self, uuids: list[str], start: Optional[int], limit: Optional[int], includeSummary: Optional[bool]) -> VsanSyncingObjectQueryResult: ...
   def QueryHostDrsStats(self, hostUuids: list[str], vms: list[str], hostIndex: Optional[int]) -> DrsStats: ...
   def UnmountDiskMappingEx(self, mappings: list[DiskMapping], maintenanceSpec: Optional[MaintenanceSpec], timeout: Optional[int], evacReason: Optional[str]) -> Task: ...
   def QueryHostStatusEx(self, clusterUuids: list[str]) -> list[ClusterStatus]: ...
   def WipeDisk(self, disks: list[str]) -> Task: ...
   def QueryWipeDiskStatus(self, disks: list[str]) -> list[WipeDiskStatus]: ...
   def AbortWipeDisk(self, disks: list[str]) -> list[AbortWipeDiskStatus]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim.cluster import Action

class HostInfraUpdateHaModeAction(Action):
   class OperationType(Enum):
      enterQuarantine: ClassVar['OperationType'] = 'enterQuarantine'
      exitQuarantine: ClassVar['OperationType'] = 'exitQuarantine'
      enterMaintenance: ClassVar['OperationType'] = 'enterMaintenance'

   operationType: str



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vsan import CapacityReservationInfo
from pyVmomi.vim.vsan import VsanHealthThreshold

class VsanClusterWhatifHostFailuresResult(DynamicData):
   numFailures: long
   totalUsedCapacityB: long
   totalCapacityB: long
   totalRcReservationB: long
   totalRcSizeB: long
   usedComponents: long
   totalComponents: long
   componentLimitHealth: Optional[str] = None
   diskFreeSpaceHealth: Optional[str] = None
   rcFreeReservationHealth: Optional[str] = None
   slackSpaceCapRequired: Optional[long] = None
   diskSpaceThreshold: Optional[VsanHealthThreshold] = None
   capacityReservationInfo: Optional[CapacityReservationInfo] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim.view import ManagedObjectView
from pyVmomi.vim.view import View

class ListView(ManagedObjectView):
   def Modify(self, add: list[ManagedObject], remove: list[ManagedObject]) -> list[ManagedObject]: ...
   def Reset(self, obj: list[ManagedObject]) -> list[ManagedObject]: ...
   def ResetFromView(self, view: View) -> NoReturn: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.VmomiSupport import long

from pyVmomi.vim.fault import InsufficientResourcesFault

class InsufficientNetworkResourcePoolCapacity(InsufficientResourcesFault):
   dvsName: str
   dvsUuid: str
   resourcePoolKey: str
   available: long
   requested: long
   device: list[str] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import ClusterComputeResource
from pyVmomi.vim import HostSystem
from pyVmomi.vim import Task

from pyVmomi.vim.cluster import VsanDiskFormatConversionCheckResult
from pyVmomi.vim.cluster import VsanDiskFormatConversionSpec
from pyVmomi.vim.cluster import VsanUpgradeStatusEx

class VsanUpgradeSystemEx(ManagedObject):
   def PerformUpgrade(self, cluster: ClusterComputeResource, performObjectUpgrade: Optional[bool], downgradeFormat: Optional[bool], allowReducedRedundancy: Optional[bool], excludeHosts: list[HostSystem], spec: Optional[VsanDiskFormatConversionSpec]) -> Task: ...
   def PerformUpgradePreflightAsyncCheck(self, cluster: ClusterComputeResource, downgradeFormat: Optional[bool], spec: Optional[VsanDiskFormatConversionSpec]) -> Task: ...
   def PerformUpgradePreflightCheck(self, cluster: ClusterComputeResource, downgradeFormat: Optional[bool], spec: Optional[VsanDiskFormatConversionSpec]) -> VsanDiskFormatConversionCheckResult: ...
   def RetrieveSupportedFormatVersion(self, cluster: ClusterComputeResource) -> int: ...
   def QueryUpgradeStatus(self, cluster: ClusterComputeResource) -> VsanUpgradeStatusEx: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class ConfigInfo(DynamicData):
   class HostDefaultInfo(DynamicData):
      uuid: Optional[str] = None
      autoClaimStorage: Optional[bool] = None
      checksumEnabled: Optional[bool] = None

   enabled: Optional[bool] = None
   defaultConfig: Optional[HostDefaultInfo] = None
   vsanEsaEnabled: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.cluster import DasAamNodeState
from pyVmomi.vim.cluster import DasHostInfo

class DasAamHostInfo(DasHostInfo):
   hostDasState: list[DasAamNodeState] = []
   primaryHosts: list[str] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import KeyValue

from pyVmomi.vmodl import DynamicData

class SnmpSystem(ManagedObject):
   class SnmpConfigSpec(DynamicData):
      class Destination(DynamicData):
         hostName: str
         port: int
         community: str

      enabled: Optional[bool] = None
      port: Optional[int] = None
      readOnlyCommunities: list[str] = []
      trapTargets: list[Destination] = []
      option: list[KeyValue] = []

   class AgentLimits(DynamicData):
      class Capability(Enum):
         COMPLETE: ClassVar['Capability'] = 'COMPLETE'
         DIAGNOSTICS: ClassVar['Capability'] = 'DIAGNOSTICS'
         CONFIGURATION: ClassVar['Capability'] = 'CONFIGURATION'

      maxReadOnlyCommunities: int
      maxTrapDestinations: int
      maxCommunityLength: int
      maxBufferSize: int
      capability: Capability

   @property
   def configuration(self) -> SnmpConfigSpec: ...
   @property
   def limits(self) -> AgentLimits: ...

   def ReconfigureSnmpAgent(self, spec: SnmpConfigSpec) -> NoReturn: ...
   def SendTestNotification(self) -> NoReturn: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .ApplyRecommendationResult import ApplyRecommendationResult as ApplyRecommendationResult
from .AutomationConfig import AutomationConfig as AutomationConfig
from .ConfigInfo import ConfigInfo as ConfigInfo
from .ConfigSpec import ConfigSpec as ConfigSpec
from .HbrDiskMigrationAction import HbrDiskMigrationAction as HbrDiskMigrationAction
from .IoLoadBalanceConfig import IoLoadBalanceConfig as IoLoadBalanceConfig
from .OptionSpec import OptionSpec as OptionSpec
from .PlacementAffinityRule import PlacementAffinityRule as PlacementAffinityRule
from .PlacementRankResult import PlacementRankResult as PlacementRankResult
from .PlacementRankSpec import PlacementRankSpec as PlacementRankSpec
from .PlacementRankVmSpec import PlacementRankVmSpec as PlacementRankVmSpec
from .PodConfigInfo import PodConfigInfo as PodConfigInfo
from .PodConfigSpec import PodConfigSpec as PodConfigSpec
from .PodSelectionSpec import PodSelectionSpec as PodSelectionSpec
from .SpaceLoadBalanceConfig import SpaceLoadBalanceConfig as SpaceLoadBalanceConfig
from .StorageMigrationAction import StorageMigrationAction as StorageMigrationAction
from .StoragePlacementAction import StoragePlacementAction as StoragePlacementAction
from .StoragePlacementResult import StoragePlacementResult as StoragePlacementResult
from .StoragePlacementSpec import StoragePlacementSpec as StoragePlacementSpec
from .VirtualDiskAntiAffinityRuleSpec import VirtualDiskAntiAffinityRuleSpec as VirtualDiskAntiAffinityRuleSpec
from .VirtualDiskRuleSpec import VirtualDiskRuleSpec as VirtualDiskRuleSpec
from .VmConfigInfo import VmConfigInfo as VmConfigInfo
from .VmConfigSpec import VmConfigSpec as VmConfigSpec



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.encryption import CryptoSpec

from pyVmomi.vim.vm import BaseIndependentFilterSpec
from pyVmomi.vim.vm import ProfileSpec

from pyVmomi.vim.vm.device import VirtualDevice

class VirtualDeviceSpec(DynamicData):
   class Operation(Enum):
      add: ClassVar['Operation'] = 'add'
      remove: ClassVar['Operation'] = 'remove'
      edit: ClassVar['Operation'] = 'edit'

   class FileOperation(Enum):
      create: ClassVar['FileOperation'] = 'create'
      destroy: ClassVar['FileOperation'] = 'destroy'
      replace: ClassVar['FileOperation'] = 'replace'

   class BackingSpec(DynamicData):
      parent: Optional[BackingSpec] = None
      crypto: Optional[CryptoSpec] = None

   class ChangeMode(Enum):
      fail: ClassVar['ChangeMode'] = 'fail'
      skip: ClassVar['ChangeMode'] = 'skip'

   operation: Optional[Operation] = None
   fileOperation: Optional[FileOperation] = None
   device: VirtualDevice
   profile: list[ProfileSpec] = []
   backing: Optional[BackingSpec] = None
   filterSpec: list[BaseIndependentFilterSpec] = []
   changeMode: Optional[str] = None
